@@ -1678,11 +1678,11 @@ void getReference(Abs_T *v, void getData(Abs_T *v))
     *v = OT_GET(Abs_T,pcimg->getmap,getid);
   }
   else
-  {
+  { OT_Obj dmy = NULL;
     assert0(getid == OT_CNT(pcimg->getmap),"out of sync");
     OT_PUSH(NULL,pcimg->getmap);
     getData(v);
-    OT_UPD(Abs_T,pcimg->getmap,getid,*v);
+    dmy = OT_UPD(Abs_T,pcimg->getmap,getid,*v);
   }
 }
 
@@ -1698,10 +1698,10 @@ void fgetReference
     *v = OT_GET(Abs_T,img->getmap,getid);
   }
   else
-  {
+  { OT_Obj dmy = NULL;
     assert0(getid == OT_CNT(img->getmap),"out of sync");
     OT_PUSH(NULL,img->getmap);
     getData(img,v);
-    OT_UPD(Abs_T,img->getmap,getid,*v);
+    dmy = OT_UPD(Abs_T,img->getmap,getid,*v);
   }
 }
