@@ -41,19 +41,33 @@
 /*I------------------- Production types: special recognizer ----------------- */
 
 bool nilProd(string prod)
-/* production name = "nil" ? */
+/* production name = "nil#*" ? */
 {
+  /*
   return( ! strcmp("nil",prod) );
+  */
+  return
+  ( 
+    strlen(prod) >= 3 && ! strncmp("nil",prod,3) && 
+    (*(prod+3) == '\0' || isdigit(prod[3])) 
+  );
 }
 
 bool consProd(string prod)
-/* production name = "cons" ? */
+/* production name = "cons#*" ? */
 {
+  /*
   return( ! strcmp("cons",prod) );
+  */
+  return
+  ( 
+    strlen(prod) >= 4 && ! strncmp("cons",prod,4) && 
+    (*(prod+4) == '\0' || isdigit(prod[4])) 
+  );
 }
 
 bool ignProd(string prod)
-/* production name = "ign#*" ? */
+/* production name = "ign#+" ? */
 {
   return( strlen(prod) >= 4 && ! strncmp("ign",prod,3) && isdigit(prod[3]) );
 }
