@@ -338,7 +338,7 @@ void GS_fprint_ucs4(FILE* fp, wc_string ws, c_bool raw)
         fprintf(fp,"%02x",b);
     }
     else 
-      fprintf(fp,"%08lx",ws[i]);
+      fprintf(fp,"%08lx",(long unsigned int)ws[i]);
   }
 }
 
@@ -1008,7 +1008,7 @@ c_bool GS_stream_string_insert
   { unsigned int bytesleft = gstream->gsd_len-gstream->gsd_pos;
     c_byte* b = (c_byte*)NewMem(bytesleft+1);
     memcpy(b,((c_string)gstream->gsd)+gstream->gsd_pos,bytesleft);
-    if( GS_putbytes_to_string(gstream,s,len) >= len &&
+    if( GS_putbytes_to_string(gstream,(c_byte*)s,len) >= len &&
         GS_putbytes_to_string(gstream,b,bytesleft) >= bytesleft )
     {
       FreeMem(b); return C_True;
