@@ -619,14 +619,14 @@ void HMP_getItrAsg(HMP_Itr i, HMP_Dom *d, HMP_Rng *r)
         for (ItrVar = MAP_newItr(MapExpr);          \
              MAP_emptyItr(ItrVar)                   \
              ? (MAP_freeItr(ItrVar),         False) \
-             : (MAP_getItr(ItrVar, &DomVar), True );\
+             : (MAP_getItr(ItrVar, ((StdCPtr)&DomVar)), True );\
             )
 
 #define MAP_forItrAsg(DomVar,RngVar,ItrVar,MapExpr)             \
         for (ItrVar = MAP_newItr(MapExpr);                      \
              MAP_emptyItr(ItrVar)                               \
              ? (MAP_freeItr(ItrVar),         False)             \
-             : (MAP_getItrAsg(ItrVar, &DomVar, &RngVar), True );\
+             : (MAP_getItrAsg(ItrVar, ((StdCPtr)&DomVar), ((StdCPtr)&RngVar)), True );\
             )
 /*DOC_INTERFACE_COPY_OFF*/
 
