@@ -415,7 +415,7 @@ static bool JoinColEqual(HS_Elm l, HS_Elm r, StdCPtr* cols)
   for( i=1, j=2; i < cnt; i+=2, j+=2 )
   { bool (*equal)(HS_Dom l,HS_Dom r) = HS__TYP_EQUAL(ltyp,intCAST(cols[i]));
 
-    if( ! (*equal)(HS__TPL_DOM(l,(int)cols[i]),HS__TPL_DOM(r,intCAST(cols[j]))) ) 
+    if( ! (*equal)(HS__TPL_DOM(l,intCAST(cols[i])),HS__TPL_DOM(r,intCAST(cols[j]))) ) 
       return( False );
   }
   return( True );
