@@ -34,7 +34,14 @@
  supports simple text replacement. Each occurance of a key in the given text will
  be replaced by the associated value.
 
-  5. The following functions support the removement/extraction of HTML/XML-tags, 
+  5. The primitive
+
+  |      bool Line_split(string txt, string pat, string* left, string* right)
+
+ supports simple text separation. If 'pat' is a substring of 'txt' the prefix
+ will be assigned to 'left' and the suffix to 'right'.
+
+  6. The following functions support the removement/extraction of HTML/XML-tags, 
      C-comments and spaces in a given text.
 
   |      string Line_withTag(string txt)
@@ -45,7 +52,7 @@
   |      string Line_withoutWhite(string txt)
   |      string Line_clip[L|R](string txt)
 
-  6. Finally this module defines a set of functions for URI-Creation/Evaluation. ( RFC 2396 )
+  7. Finally this module defines a set of functions for URI-Creation/Evaluation. ( RFC 2396 )
 
 */
 
@@ -487,6 +494,27 @@ string Line_replace(string txt, MAP(symbol,symbol) ReplaceRules)
   return Sink_close(snk);
 }
 
+c_bool Line_split(c_string txt, c_string pat, c_string* left, c_string* right)
+/* separates 'txt'; allocs memory:
+   'txt' = 'pat' . suffix          --> RC = true, *left=NULL,   *right=suffix
+   'txt' = prefix . 'pat'          --> RC = true, *left=prefix, *right=NULL
+   'txt' = prefix . 'pat' . suffix --> RC = true, *left=prefix, *right=suffix
+   else                            --> RC = false
+*/
+{ c_string tmp = strstr(txt,pat);
+  *left = *right = (c_string)NULL;
+  if( tmp != (c_string)NULL )
+  { int len = strlen(pat);
+    if( tmp != txt )
+    {
+      *left = SubStrCopy(txt,tmp-txt); 
+    }
+    if( *(tmp+len) != '\0' ) *right = StrCopy(tmp+len);
+    return C_True;
+  }
+  return C_False;
+}
+
 /*I-------------------------- URI Generation & Evaluation ----------------- */
 
 /*DOC_INTERFACE*/
