@@ -749,6 +749,8 @@ PLR_Tab PLR_copyTab(PLR_Tab PTab)
         );
     }
     else tab->Prod[i].symbols = tab->Prod[i].symfrms = (int*)NULL;
+    tab->Prod[i].dsymidx = PLR_T_IMP(PTab)->Prod[i].dsymidx;
+    tab->Prod[i].dsymsym = PLR_T_IMP(PTab)->Prod[i].dsymsym;
   }
 
   /* Parse-Tabellen */
@@ -991,6 +993,28 @@ int PLR_prodSymbol(PLR_Tab PTab, int prodId, int psymId)
   return( PLR_T_IMP(PTab)->Prod[prodId].symbols[psymId] );
 }
 
+int PLR_prodDSymIdx(PLR_Tab PTab, int prodId)
+/* dynamic symbol member index of production 'prodId' 
+   of parse table 'PTab' or -1
+   [prodId=0..PCnt-1] --> [0..PSCnt-1]
+*/
+{
+  BUG_NULL(PTab);
+  BUG_PLR_PROD(prodId); 
+  return( PLR_T_IMP(PTab)->Prod[prodId].dsymidx );
+}
+
+int PLR_prodDSymSym(PLR_Tab PTab, int prodId)
+/* dynamic symbol member of production 'prodId' 
+   of parse table 'PTab' or -1
+   [prodId=0..PCnt-1] --> [0..SymbolCnt-1]
+*/
+{
+  BUG_NULL(PTab);
+  BUG_PLR_PROD(prodId); 
+  return( PLR_T_IMP(PTab)->Prod[prodId].dsymsym );
+}
+
 int PLR_prodSymFrm(PLR_Tab PTab, int prodId, int psymId)
 /* layout info for production 'prodId' and member 'psymId' 
    of parse table 'PTab'
