@@ -35,13 +35,15 @@ typedef struct _KFGHEAD {
 
 typedef struct _KFGPROD {
 /* Production */
-  c_string pname;   /* Production name                            */
+  c_string pname;   /* Production name[@<dsymidx>=<dsymsym>]      */
   int      method;  /* Production layout hint                     */
   int      id;      /* Nonterminal ( left production side )       */
   int      symcnt;  /* Number of production symbols               */
   int*     symbols; /* Production symbols ( Token, Nonterminals ) */
   int*     symfrms; /* Production symbol layout hints             */
                     /* ( != 0 ==> new line )                      */
+  int      dsymidx; /* Index of dynamic production symbol or -1   */
+  int      dsymsym; /* Introduced dynamic production symbol or -1 */
 } KFGPROD;
 
 typedef struct _LALR_1 {
