@@ -204,6 +204,7 @@ static void printKfgProds
       );
     else                  
       fprintf(fp,"(int*)NULL, (int*)NULL");
+    fprintf(fp,", %d, %d", Prods[i].dsymidx, Prods[i].dsymsym);
     fprintf(fp," }%s", ( i < ProdCnt-1 ) ? "," : "");
   }
   FPNLSNL(fp,"};");
@@ -276,6 +277,8 @@ static void fputKfgProds(BinImg_T img, KFGPROD* Prods, int ProdCnt)
     fputInt(img,Prods[i].symcnt);
     for( j=0; j < Prods[i].symcnt; ++j ) fputInt(img,Prods[i].symbols[j]);
     for( j=0; j < Prods[i].symcnt; ++j ) fputInt(img,Prods[i].symfrms[j]);
+    fputInt(img,Prods[i].dsymidx);
+    fputInt(img,Prods[i].dsymsym);
   }
 }
 
@@ -325,6 +328,7 @@ static void fgetKfgProds(BinImg_T img, KFGPROD* Prods, int ProdCnt)
 
   for( i=0; i < ProdCnt; ++i )
   {
+    Prods[i].dsymidx = Prods[i].dsymsym = -1;
     fgetString(img,&Prods[i].pname);
     fgetInt(img,&Prods[i].id);
     fgetInt(img,&Prods[i].method);
@@ -337,6 +341,8 @@ static void fgetKfgProds(BinImg_T img, KFGPROD* Prods, int ProdCnt)
       for( j=0; j < Prods[i].symcnt; ++j ) fgetInt(img,&Prods[i].symfrms[j]);
     }
     else Prods[i].symbols = Prods[i].symfrms = (int*)NULL;
+    fgetInt(img,&Prods[i].dsymidx);
+    fgetInt(img,&Prods[i].dsymsym);
   }
 }
 
@@ -558,10 +564,23 @@ void PLR_Src_Source
   for( i=0; i < cnt; ++i )
   {
     fprintf(fp,"%sKFGPROD%s%s\n",prefix,nl,suffix);
-    fprintf
-    (
-      fp,"%spname=%s%s%s\n",prefix,PLR_T_IMP(PTab)->Prod[i].pname,nl,suffix
-    );
+    if( PLR_T_IMP(PTab)->Prod[i].dsymidx < 0 )
+      fprintf
+      (
+        fp,"%spname=%s%s%s\n",prefix,PLR_T_IMP(PTab)->Prod[i].pname,nl,suffix
+      );
+    else
+    {
+      fprintf
+      (
+        fp,"%spname=%s@%d=%d%s%s\n",
+        prefix,
+        PLR_T_IMP(PTab)->Prod[i].pname,
+        PLR_T_IMP(PTab)->Prod[i].dsymidx,
+        PLR_T_IMP(PTab)->Prod[i].dsymsym,
+        nl,suffix
+      );
+    }
     fprintf
     (
       fp,"%smethod=%d%s%s\n",prefix,PLR_T_IMP(PTab)->Prod[i].method,nl,suffix
