@@ -551,6 +551,12 @@ PT_Term PT_nthST(PT_Term PTree, int nth, bool (*filter)(PT_Term PTree))
     return PT_nthST_ex(PTree,nth,default_filter_ex,filter);
 }
 
+static bool filterMember(PT_Term PTree)
+/* Type(PTree) not in { NTM, TOK, KEY } ? */
+{
+  return( CFG_COM(PT_M_STP(PTree)) );
+}
+
 static bool filterNtmOrTok(PT_Term PTree)
 /* Type(PTree) not in { NTM, TOK } ? */
 {
@@ -587,6 +593,15 @@ PT_Term PT_nthSymbol(PT_Term PTree, symbol cfgsym, int nth, bool filter)
   else return( PT_nthST(PTree,nth,filterNtmOrTok) );
 }
 
+PT_Term PT_nthMember(PT_Term PTree, int nth)
+/* 'nth' token, keyword or nonterminal node
+   ( skipping comments )
+   within child list of node 'PTree' [nth=1..PT_symbolCnt] 
+*/
+{
+  return( PT_nthST(PTree,nth,filterMember) );
+}
+
 PT_Term PT_r_find
         (
           PT_Term PTree, bool (*pred)(PT_Term PTree, StdCPtr any), StdCPtr any
