@@ -15,6 +15,7 @@
 
 #include "prs.h"
 #include "sink.h"
+#include "hmap.h"
 #include "gstream.h"
 
 /*!!
@@ -40,38 +41,41 @@ AbstractType(PT_Cfg); /* Abstract parse term configuration type */
 
 typedef struct _PTCFG {
 /* Parse Term Configuration */
-  Abs_T         PlrCfg;     /* Parser Configuration       */
+  Abs_T         PlrCfg;      /* Parser Configuration       */
   Abs_T (*getPTCfg)(Abs_T PlrCfg);
-                    /* get term generation configuration  */
-  Abs_T         ExtScnCfg;  /* ext. Scanner Configuration */
-  Abs_T         cStream;    /* Scanner / Stream           */
-  SF_scan       nextTok;    /* CB for Stream_next         */
-  SF_tok        tokID;      /* CB for Stream_ctid         */
-  SF_symbol     tokSym;     /* CB for Stream_csym         */
-  SF_symbol     streamSym;  /* CB for Stream_cfil         */
-  SF_pos        tokRow;     /* CB for Stream_clin         */
-  SF_pos        tokCol;     /* CB for Stream_ccol         */
-  SF_flag       unicode;    /* CB for Stream_unicode      */
-  symbol*       CfgSyms;    /* Grammar Symbols            */
-  symbol*       PrdSyms;    /* Production Symbols         */
-  symbol        ErrSym;     /* error symbol               */
-  bool          list;       /* ComTree, Tree are lists ?  */
-  StdCPtr       ComTree;    /* Comment Tree ( List )      */
-  StdCPtr       Tree;       /* Derivation Tree ( List )   */
-  int           ErrCnt;     /* Syntax Error Count         */ 
-  Any_T         CnvCtx;     /* conversion context         */
+                     /* get term generation configuration  */
+  Abs_T         ExtScnCfg;   /* ext. Scanner Configuration */
+  Abs_T         cStream;     /* Scanner / Stream           */
+  SF_scan       nextTok;     /* CB for Stream_next         */
+  SF_tok        tokID;       /* CB for Stream_ctid         */
+  SF_symbol     tokSym;      /* CB for Stream_csym         */
+  SF_symbol     streamSym;   /* CB for Stream_cfil         */
+  SF_pos        tokRow;      /* CB for Stream_clin         */
+  SF_pos        tokCol;      /* CB for Stream_ccol         */
+  SF_flag       unicode;     /* CB for Stream_unicode      */
+  SF_defDynID   defDynKeyID; /* CB for Stream_defDynKeyId  */
+  PF_dynprod    prodDynIdx;  /* CB for PLR_prodDSymIdx     */
+  PF_dynprod    prodDynSym;  /* CB for PLR_prodDSymSym     */
+  symbol*       CfgSyms;     /* Grammar Symbols            */
+  symbol*       PrdSyms;     /* Production Symbols         */
+  symbol        ErrSym;      /* error symbol               */
+  bool          list;        /* ComTree, Tree are lists ?  */
+  StdCPtr       ComTree;     /* Comment Tree ( List )      */
+  StdCPtr       Tree;        /* Derivation Tree ( List )   */
+  int           ErrCnt;      /* Syntax Error Count         */ 
+  Any_T         CnvCtx;      /* conversion context         */
   symbol (*convertTok)(symbol tok, symbol val);
-                   /* external token conversion function  */
+                    /* external token conversion function  */
   PT_Term (*convertNtm)(PT_Term Tree);
-             /* external nonterminal conversion function  */
+              /* external nonterminal conversion function  */
   void (*printMsg)(string msg);
-                      /* external message print function  */
-  Any_T         eCfg;       /* embedded configuration     */
-  Any_T         ePlrCtx;    /* embedded parser context    */
+                       /* external message print function  */
+  Any_T         eCfg;        /* embedded configuration     */
+  Any_T         ePlrCtx;     /* embedded parser context    */
   Abs_T (*newEParser)(Any_T ePlrCtx,c_string language);    
-                            /* new embedded parse table   */
+                             /* new embedded parse table   */
   void (*freeEParser)(Abs_T eParser);    
-                            /* free embedded parse table  */
+                             /* free embedded parse table  */
 } PTCFG;
 
 
@@ -113,6 +117,30 @@ static string PT_curSy_ext(AbsPlr_T pconfig)
   return symbolToString((*Cfg->tokSym)(Cfg->cStream));
 }
 
+static void PT_dynTokenError(PTCFG* Cfg, PT_Term t, symbol dyntok)
+{ string msg;
+  msg = Str_printf
+        (
+          "%s(%d,%d) : syntax error (dynamic token '%s')\n",
+          symbolToString(PT_file(t)),
+          PT_row(t),
+          PT_col(t),
+          symbolToString(dyntok)
+        );
+  if( Cfg->printMsg != (void (*)(string msg))NULL )
+    (*Cfg->printMsg)(msg);
+  else 
+  if( printMsg != (void (*)(string msg))NULL )
+    (*printMsg)(msg);
+  else 
+  if( !(*Cfg->unicode)(Cfg->cStream) )
+    fprintf(STDERR,"%s",msg);
+  else
+    fprint_raw(STDERR,msg,-1);
+  FreeMem(msg);
+  ++Cfg->ErrCnt;
+}
+
 static void PT_synError_aux(PTCFG* Cfg)
 { string msg;
   msg = Str_printf
@@ -333,6 +361,7 @@ static StdCPtr CPT_reduce
                 );
   }
   else
+  { int dynidx = -1, dynsym = -1;
     Cfg->Tree = PT_updPos
                 (
                   PT_newNtNode
@@ -343,6 +372,21 @@ static StdCPtr CPT_reduce
                   ),
                   (*Cfg->streamSym)(Cfg->cStream),row,col
                 );
+    /* handle dynamic token introduction */
+    dynidx = (*Cfg->prodDynIdx)(parser,prodId);
+    if( dynidx >= 0 && dynidx < symcnt )
+    { PT_Term dt;
+      dynsym = (*Cfg->prodDynSym)(parser,prodId);
+      dt = PT_nthMember(Cfg->Tree, dynidx+1);
+      if( dt != (PT_Term)NULL && PT_isToken(dt) )
+      {
+        if( ! (*Cfg->defDynKeyID)(Cfg->cStream,PT_value(dt),dynsym) )
+        {
+          PT_dynTokenError(Cfg, dt, Cfg->CfgSyms[dynsym]);
+        }
+      }
+    }
+  }
 /*
 ....
   Cfg->Tree = PT_consT((PT_Term)Cfg->Tree,(PT_Term)NULL);
@@ -426,6 +470,7 @@ static StdCPtr XPT_reduce
                 );
   }
   else
+  { int dynidx = -1, dynsym = -1;
     Cfg->Tree = PT_updPos
                 (
                   XPT_newNtNode
@@ -436,6 +481,21 @@ static StdCPtr XPT_reduce
                   ),
                   (*Cfg->streamSym)(Cfg->cStream),row,col
                 );
+    /* handle dynamic token introduction */
+    dynidx = (*Cfg->prodDynIdx)(parser,prodId);
+    if( dynidx >= 0 && dynidx < symcnt )
+    { PT_Term dt;
+      dynsym = (*Cfg->prodDynSym)(parser,prodId);
+      dt = PT_nthMember(Cfg->Tree, dynidx+1);
+      if( dt != (PT_Term)NULL && PT_isToken(dt) )
+      {
+        if( ! (*Cfg->defDynKeyID)(Cfg->cStream,PT_value(dt),dynsym) )
+        {
+          PT_dynTokenError(Cfg, dt, Cfg->CfgSyms[dynsym]);
+        }
+      }
+    }
+  }
 /*
 ....
   Cfg->Tree = <Transformation>((PT_Term)Cfg->Tree);
@@ -490,32 +550,53 @@ PT_Cfg PT_init(PLR_Tab PTab, Scn_Stream cStream)
       tokcnt = PLR_tokenCnt(PTab),
       prdcnt = PLR_prodCnt(PTab), typ, i;
   PLR_Pdf Pdf; PTCFG* Cfg; bool oflg = False;
+  MAPTY T_dynToken = MAP_newTyp
+                     (
+                       primCopy, primFree, primEqual, primHash, primCopy, primFree
+                     );
+  MAP(long,_) dynToken = MAP_newMap(T_dynToken);
   BUG_NULL(cStream);
-  Cfg             = (PTCFG*)NewMem(sizeof(PTCFG));
-  Cfg->ExtScnCfg  = (Abs_T)NULL;
-  Cfg->cStream    = cStream;
-  Cfg->nextTok    = Stream_next;
-  Cfg->tokID      = Stream_ctid;
-  Cfg->tokSym     = Stream_csym;
-  Cfg->streamSym  = Stream_cfil;
-  Cfg->tokRow     = Stream_clin;
-  Cfg->tokCol     = Stream_ccol; 
-  Cfg->unicode    = Stream_unicode;
-  Cfg->ErrCnt     = 0;
-  Cfg->list       = False;
-  Cfg->ErrSym     = stringToSymbol("[error]");
-  Cfg->ComTree    = (StdCPtr)NULL;
-  Cfg->Tree       = (StdCPtr)NULL;
-  Cfg->CnvCtx     = (Any_T)NULL;
-  Cfg->convertTok = (symbol (*)(symbol tok, symbol val))NULL;
-  Cfg->convertNtm = (PT_Term (*)(PT_Term Tree))NULL;
-  Cfg->printMsg   = (void (*)(string msg))NULL;
+  Cfg              = (PTCFG*)NewMem(sizeof(PTCFG));
+  Cfg->ExtScnCfg   = (Abs_T)NULL;
+  Cfg->cStream     = cStream;
+  Cfg->nextTok     = Stream_next;
+  Cfg->tokID       = Stream_ctid;
+  Cfg->tokSym      = Stream_csym;
+  Cfg->streamSym   = Stream_cfil;
+  Cfg->tokRow      = Stream_clin;
+  Cfg->tokCol      = Stream_ccol; 
+  Cfg->unicode     = Stream_unicode;
+  Cfg->defDynKeyID = Stream_defDynKeyId;
+  Cfg->prodDynIdx  = PLR_prodDSymIdx;
+  Cfg->prodDynSym  = PLR_prodDSymSym;
+  Cfg->ErrCnt      = 0;
+  Cfg->list        = False;
+  Cfg->ErrSym      = stringToSymbol("[error]");
+  Cfg->ComTree     = (StdCPtr)NULL;
+  Cfg->Tree        = (StdCPtr)NULL;
+  Cfg->CnvCtx      = (Any_T)NULL;
+  Cfg->convertTok  = (symbol (*)(symbol tok, symbol val))NULL;
+  Cfg->convertNtm  = (PT_Term (*)(PT_Term Tree))NULL;
+  Cfg->printMsg    = (void (*)(string msg))NULL;
+
+  Cfg->CfgSyms = (symbol*)NewMem(sizeof(symbol)*symcnt);
+  for( i=0; i < symcnt; ++i ) 
+    Cfg->CfgSyms[i] = stringToSymbol(PLR_symName(PTab,i));
+  Cfg->PrdSyms = (symbol*)NewMem(sizeof(symbol)*prdcnt);
+  for( i=0; i < prdcnt; ++i ) 
+  { int dynidx;
+    Cfg->PrdSyms[i] = stringToSymbol(PLR_prodName(PTab,i));
+    dynidx = PLR_prodDSymIdx(PTab,i);
+    if( dynidx >= 0 ) MAP_ovrdom(dynToken,PLR_prodDSymSym(PTab,i),NULL);
+  }
+
   oflg = (tokcnt > 0 && !strcmp(PLR_symName(PTab,tokcnt-1),PLR_TOK_Other));
   Stream_defEofId(cStream,-1);
   Stream_defErrId(cStream,(short)((oflg==True)?tokcnt-1:-2));
   for( i=0; i < tokcnt-(oflg==True); ++i )
   // assertion: other token is last token
   {
+    if( MAP_defined(dynToken,(long)i) ) continue;
     typ = PLR_symType(PTab,i);
     if( CFG_COM(typ) ) typ = CFG_COM_TO_TERM(typ);
     if( CFG_TOK(typ) ) Stream_defTokId(cStream,PLR_symName(PTab,i),(short)i);
@@ -533,12 +614,7 @@ PT_Cfg PT_init(PLR_Tab PTab, Scn_Stream cStream)
       Stream_eterm_set(cStream,Cfg,PT_eTerm,PT_eAccept);
     }
   }
-  Cfg->CfgSyms = (symbol*)NewMem(sizeof(symbol)*symcnt);
-  for( i=0; i < symcnt; ++i ) 
-    Cfg->CfgSyms[i] = stringToSymbol(PLR_symName(PTab,i));
-  Cfg->PrdSyms = (symbol*)NewMem(sizeof(symbol)*prdcnt);
-  for( i=0; i < prdcnt; ++i ) 
-    Cfg->PrdSyms[i] = stringToSymbol(PLR_prodName(PTab,i));
+
   Pdf = PLR_createPdf(PTab,Cfg);
   PLR_addGetF(Pdf,PT_get);
   PLR_addCurSyF(Pdf,PT_curSy);
@@ -552,6 +628,7 @@ PT_Cfg PT_init(PLR_Tab PTab, Scn_Stream cStream)
   Cfg->ePlrCtx     = (Any_T)NULL;
   Cfg->newEParser  = (Abs_T (*)(Any_T ePlrCtx,c_string language))NULL;
   Cfg->freeEParser = (void (*)(Abs_T eParser))NULL;
+  MAP_freeMap(dynToken); MAP_freeTyp(T_dynToken);
   return( (PT_Cfg)Cfg );
 }
 
@@ -566,36 +643,57 @@ PT_Cfg PT_init_extscn(PLR_Tab PTab, AbsScn_T sconfig)
   PLR_Pdf Pdf; PTCFG* Cfg; bool oflg = False;
   SF_defID defEofID, defErrID; SF_defTxtID defTokID, defKeyID;
   SF_defWCTxtID defWCKeyID;
-  Cfg                    = (PTCFG*)NewMem(sizeof(PTCFG));
-  Cfg->ExtScnCfg         = sconfig;
-  assert0(Cfg->cStream   = AS_getScanner(sconfig), "");
-  assert0(Cfg->nextTok   = AS_getFunNextTok(sconfig), "");
-  assert0(Cfg->tokID     = AS_getFunTokID(sconfig), "");
-  assert0(Cfg->tokSym    = AS_getFunTokSym(sconfig), "");
-  assert0(Cfg->streamSym = AS_getFunStreamSym(sconfig), "");
-  assert0(Cfg->tokRow    = AS_getFunTokRow(sconfig), "");
-  assert0(Cfg->tokCol    = AS_getFunTokCol(sconfig), ""); 
-  assert0(Cfg->unicode   = AS_getFunUnicode(sconfig), "");
-  Cfg->ErrCnt            = 0;
-  Cfg->list              = False;
-  Cfg->ErrSym            = stringToSymbol("[error]");
-  Cfg->ComTree           = (StdCPtr)NULL;
-  Cfg->Tree              = (StdCPtr)NULL;
-  Cfg->CnvCtx            = (Any_T)NULL;
-  Cfg->convertTok        = (symbol (*)(symbol tok, symbol val))NULL;
-  Cfg->convertNtm        = (PT_Term (*)(PT_Term Tree))NULL;
-  Cfg->printMsg          = (void (*)(string msg))NULL;
+  MAPTY T_dynToken = MAP_newTyp
+                     (
+                       primCopy, primFree, primEqual, primHash, primCopy, primFree
+                     );
+  MAP(long,_) dynToken = MAP_newMap(T_dynToken);
+  Cfg                      = (PTCFG*)NewMem(sizeof(PTCFG));
+  Cfg->ExtScnCfg           = sconfig;
+  assert0(Cfg->cStream     = AS_getScanner(sconfig), "");
+  assert0(Cfg->nextTok     = AS_getFunNextTok(sconfig), "");
+  assert0(Cfg->tokID       = AS_getFunTokID(sconfig), "");
+  assert0(Cfg->tokSym      = AS_getFunTokSym(sconfig), "");
+  assert0(Cfg->streamSym   = AS_getFunStreamSym(sconfig), "");
+  assert0(Cfg->tokRow      = AS_getFunTokRow(sconfig), "");
+  assert0(Cfg->tokCol      = AS_getFunTokCol(sconfig), ""); 
+  assert0(Cfg->unicode     = AS_getFunUnicode(sconfig), "");
+  assert0(Cfg->defDynKeyID = AS_getFunDefDynKeyID(sconfig), "");
+  Cfg->prodDynIdx          = PLR_prodDSymIdx;
+  Cfg->prodDynSym          = PLR_prodDSymSym;
+  Cfg->ErrCnt              = 0;
+  Cfg->list                = False;
+  Cfg->ErrSym              = stringToSymbol("[error]");
+  Cfg->ComTree             = (StdCPtr)NULL;
+  Cfg->Tree                = (StdCPtr)NULL;
+  Cfg->CnvCtx              = (Any_T)NULL;
+  Cfg->convertTok          = (symbol (*)(symbol tok, symbol val))NULL;
+  Cfg->convertNtm          = (PT_Term (*)(PT_Term Tree))NULL;
+  Cfg->printMsg            = (void (*)(string msg))NULL;
+
+  Cfg->CfgSyms = (symbol*)NewMem(sizeof(symbol)*symcnt);
+  for( i=0; i < symcnt; ++i ) 
+    Cfg->CfgSyms[i] = stringToSymbol(PLR_symName(PTab,i));
+  Cfg->PrdSyms = (symbol*)NewMem(sizeof(symbol)*prdcnt);
+  for( i=0; i < prdcnt; ++i ) 
+  { int dynidx;
+    Cfg->PrdSyms[i] = stringToSymbol(PLR_prodName(PTab,i));
+    dynidx = PLR_prodDSymIdx(PTab,i);
+    if( dynidx >= 0 ) MAP_ovrdom(dynToken,PLR_prodDSymSym(PTab,i),NULL);
+  }
+
   oflg = (tokcnt > 0 && !strcmp(PLR_symName(PTab,tokcnt-1),PLR_TOK_Other));
-  assert0( defEofID   = AS_getFunDefEofID(sconfig), "");
-  assert0( defErrID   = AS_getFunDefErrID(sconfig), "");
-  assert0( defTokID   = AS_getFunDefTokID(sconfig), "");
-  assert0( defKeyID   = AS_getFunDefKeyID(sconfig), "");
-  assert0( defWCKeyID = AS_getFunDefWCKeyID(sconfig), "");
+  assert0( defEofID        = AS_getFunDefEofID(sconfig), "");
+  assert0( defErrID        = AS_getFunDefErrID(sconfig), "");
+  assert0( defTokID        = AS_getFunDefTokID(sconfig), "");
+  assert0( defKeyID        = AS_getFunDefKeyID(sconfig), "");
+  assert0( defWCKeyID      = AS_getFunDefWCKeyID(sconfig), "");
   (*defEofID)(Cfg->cStream,-1);
   (*defErrID)(Cfg->cStream,(short)((oflg==True)?tokcnt-1:-2));
   for( i=0; i < tokcnt-(oflg==True); ++i )
   // assertion: other token is last token
   {
+    if( MAP_defined(dynToken,(long)i) ) continue;
     typ = PLR_symType(PTab,i);
     if( CFG_COM(typ) ) typ = CFG_COM_TO_TERM(typ);
     if( CFG_TOK(typ) ) (*defTokID)(Cfg->cStream,PLR_symName(PTab,i),(short)i);
@@ -613,12 +711,7 @@ PT_Cfg PT_init_extscn(PLR_Tab PTab, AbsScn_T sconfig)
       AS_setETermInfo(sconfig,Cfg,PT_eTerm,PT_eAccept);
     }
   }
-  Cfg->CfgSyms = (symbol*)NewMem(sizeof(symbol)*symcnt);
-  for( i=0; i < symcnt; ++i ) 
-    Cfg->CfgSyms[i] = stringToSymbol(PLR_symName(PTab,i));
-  Cfg->PrdSyms = (symbol*)NewMem(sizeof(symbol)*prdcnt);
-  for( i=0; i < prdcnt; ++i ) 
-    Cfg->PrdSyms[i] = stringToSymbol(PLR_prodName(PTab,i));
+
   Pdf = PLR_createPdf(PTab,Cfg);
   PLR_addGetF(Pdf,PT_get);
   PLR_addCurSyF(Pdf,PT_curSy);
@@ -632,6 +725,7 @@ PT_Cfg PT_init_extscn(PLR_Tab PTab, AbsScn_T sconfig)
   Cfg->ePlrCtx     = (Any_T)NULL;
   Cfg->newEParser  = (Abs_T (*)(Any_T ePlrCtx,c_string language))NULL;
   Cfg->freeEParser = (void (*)(Abs_T eParser))NULL;
+  MAP_freeMap(dynToken); MAP_freeTyp(T_dynToken);
   return( (PT_Cfg)Cfg );
 }
 
@@ -646,6 +740,11 @@ PT_Cfg PT_init_ext(AbsPlr_T pconfig, AbsScn_T sconfig)
   PF_symName symName; PF_symType symType; PF_prodName prodName;
   SF_defID defEofID, defErrID; SF_defTxtID defTokID, defKeyID;
   SF_defWCTxtID defWCKeyID;
+  MAPTY T_dynToken = MAP_newTyp
+                     (
+                       primCopy, primFree, primEqual, primHash, primCopy, primFree
+                     );
+  MAP(long,_) dynToken = MAP_newMap(T_dynToken);
   assert0( parser   = AP_getParser(pconfig), "");
   assert0( symCnt   = AP_getFunSymCnt(pconfig), "");
   assert0( tokCnt   = AP_getFunTokCnt(pconfig), "");
@@ -661,25 +760,40 @@ PT_Cfg PT_init_ext(AbsPlr_T pconfig, AbsScn_T sconfig)
   symcnt = (*symCnt)(parser); 
   tokcnt = (*tokCnt)(parser);
   prdcnt = (*prodCnt)(parser);
-  Cfg                    = (PTCFG*)NewMem(sizeof(PTCFG));
-  Cfg->ExtScnCfg         = sconfig;
-  assert0(Cfg->cStream   = AS_getScanner(sconfig), "");
-  assert0(Cfg->nextTok   = AS_getFunNextTok(sconfig), "");
-  assert0(Cfg->tokID     = AS_getFunTokID(sconfig), "");
-  assert0(Cfg->tokSym    = AS_getFunTokSym(sconfig), "");
-  assert0(Cfg->streamSym = AS_getFunStreamSym(sconfig), "");
-  assert0(Cfg->tokRow    = AS_getFunTokRow(sconfig), "");
-  assert0(Cfg->tokCol    = AS_getFunTokCol(sconfig), ""); 
-  assert0(Cfg->unicode   = AS_getFunUnicode(sconfig), "");
-  Cfg->ErrCnt            = 0;
-  Cfg->list              = False;
-  Cfg->ErrSym            = stringToSymbol("[error]");
-  Cfg->ComTree           = (StdCPtr)NULL;
-  Cfg->Tree              = (StdCPtr)NULL;
-  Cfg->CnvCtx            = (Any_T)NULL;
-  Cfg->convertTok        = (symbol (*)(symbol tok, symbol val))NULL;
-  Cfg->convertNtm        = (PT_Term (*)(PT_Term Tree))NULL;
-  Cfg->printMsg          = (void (*)(string msg))NULL;
+  Cfg                      = (PTCFG*)NewMem(sizeof(PTCFG));
+  Cfg->ExtScnCfg           = sconfig;
+  assert0(Cfg->cStream     = AS_getScanner(sconfig), "");
+  assert0(Cfg->nextTok     = AS_getFunNextTok(sconfig), "");
+  assert0(Cfg->tokID       = AS_getFunTokID(sconfig), "");
+  assert0(Cfg->tokSym      = AS_getFunTokSym(sconfig), "");
+  assert0(Cfg->streamSym   = AS_getFunStreamSym(sconfig), "");
+  assert0(Cfg->tokRow      = AS_getFunTokRow(sconfig), "");
+  assert0(Cfg->tokCol      = AS_getFunTokCol(sconfig), ""); 
+  assert0(Cfg->unicode     = AS_getFunUnicode(sconfig), "");
+  assert0(Cfg->defDynKeyID = AS_getFunDefDynKeyID(sconfig), "");
+  assert0(Cfg->prodDynIdx  = AP_getFunProdDynIdx(pconfig), "");
+  assert0(Cfg->prodDynSym  = AP_getFunProdDynSym(pconfig), "");
+  Cfg->ErrCnt              = 0;
+  Cfg->list                = False;
+  Cfg->ErrSym              = stringToSymbol("[error]");
+  Cfg->ComTree             = (StdCPtr)NULL;
+  Cfg->Tree                = (StdCPtr)NULL;
+  Cfg->CnvCtx              = (Any_T)NULL;
+  Cfg->convertTok          = (symbol (*)(symbol tok, symbol val))NULL;
+  Cfg->convertNtm          = (PT_Term (*)(PT_Term Tree))NULL;
+  Cfg->printMsg            = (void (*)(string msg))NULL;
+
+  Cfg->CfgSyms = (symbol*)NewMem(sizeof(symbol)*symcnt);
+  for( i=0; i < symcnt; ++i ) 
+    Cfg->CfgSyms[i] = stringToSymbol((*symName)(parser,i));
+  Cfg->PrdSyms = (symbol*)NewMem(sizeof(symbol)*prdcnt);
+  for( i=0; i < prdcnt; ++i ) 
+  { int dynidx;
+    Cfg->PrdSyms[i] = stringToSymbol((*prodName)(parser,i));
+    dynidx = (*Cfg->prodDynIdx)(parser,i);
+    if( dynidx >= 0 ) MAP_ovrdom(dynToken,(*Cfg->prodDynSym)(parser,i),NULL);
+  }
+
   oflg = (tokcnt > 0 && !strcmp((*symName)(parser,tokcnt-1),PLR_TOK_Other));
   assert0( defEofID   = AS_getFunDefEofID(sconfig), "");
   assert0( defErrID   = AS_getFunDefErrID(sconfig), "");
@@ -691,6 +805,7 @@ PT_Cfg PT_init_ext(AbsPlr_T pconfig, AbsScn_T sconfig)
   for( i=0; i < tokcnt-(oflg==True); ++i )
   // assertion: other token is last token
   {
+    if( MAP_defined(dynToken,(long)i) ) continue;
     typ = (*symType)(parser,i);
     if( CFG_COM(typ) ) typ = CFG_COM_TO_TERM(typ);
     if( CFG_TOK(typ) ) (*defTokID)(Cfg->cStream,(*symName)(parser,i),(short)i);
@@ -708,12 +823,7 @@ PT_Cfg PT_init_ext(AbsPlr_T pconfig, AbsScn_T sconfig)
       AS_setETermInfo(sconfig,Cfg,PT_eTerm,PT_eAccept);
     }
   }
-  Cfg->CfgSyms = (symbol*)NewMem(sizeof(symbol)*symcnt);
-  for( i=0; i < symcnt; ++i ) 
-    Cfg->CfgSyms[i] = stringToSymbol((*symName)(parser,i));
-  Cfg->PrdSyms = (symbol*)NewMem(sizeof(symbol)*prdcnt);
-  for( i=0; i < prdcnt; ++i ) 
-    Cfg->PrdSyms[i] = stringToSymbol((*prodName)(parser,i));
+
   AP_setExtCfg(pconfig,Cfg);
   AP_setFunNextTok(pconfig,PT_get_ext);
   AP_setFunCurTok(pconfig,PT_curSy_ext);
@@ -727,6 +837,7 @@ PT_Cfg PT_init_ext(AbsPlr_T pconfig, AbsScn_T sconfig)
   Cfg->ePlrCtx     = (Any_T)NULL;
   Cfg->newEParser  = (Abs_T (*)(Any_T ePlrCtx,c_string language))NULL;
   Cfg->freeEParser = (void (*)(Abs_T eParser))NULL;
+  MAP_freeMap(dynToken); MAP_freeTyp(T_dynToken);
   return( (PT_Cfg)Cfg );
 }
 
