@@ -683,14 +683,14 @@ static void PTP_pass3(PTP_T ctx, PT_Term tree, FILE* fp, long* row, long* col)
       while( tr < r ) 
       { 
         if( ctx->utf8 && ctx->wprint )
-          fprintf(fp,"%ld",WCHAR_LITERAL('\n'));
+          fprintf(fp,"%ld",(long int)WCHAR_LITERAL('\n'));
         else fprintf(fp,"\n");
         ++tr; 
       }
       while( tc < c ) 
       { 
         if( ctx->utf8 && ctx->wprint )
-          fprintf(fp,"%ld",WCHAR_LITERAL(' '));
+          fprintf(fp,"%ld",(long int)WCHAR_LITERAL(' '));
         else fprintf(fp," ");
         ++tc; 
       }
@@ -704,7 +704,7 @@ static void PTP_pass3(PTP_T ctx, PT_Term tree, FILE* fp, long* row, long* col)
           {
             if( ws[i] == '\n' ) 
             { 
-              fprintf(fp,"%ld",WCHAR_LITERAL('\n'));
+              fprintf(fp,"%ld",(long int)WCHAR_LITERAL('\n'));
               ++tr; tc = 0; 
             }
             else 
@@ -713,14 +713,14 @@ static void PTP_pass3(PTP_T ctx, PT_Term tree, FILE* fp, long* row, long* col)
               fprintf
               (
                 fp,"%ld%ld%ld%ld",
-                WCHAR_LITERAL(' '), WCHAR_LITERAL(' '),
-                WCHAR_LITERAL(' '), WCHAR_LITERAL(' ')
+                (long int)WCHAR_LITERAL(' '), (long int)WCHAR_LITERAL(' '),
+                (long int)WCHAR_LITERAL(' '), (long int)WCHAR_LITERAL(' ')
               );
               tc += PTP_TAB_LEN; 
             }
             else 
             { 
-              fprintf(fp,"%ld",ws[i]); 
+              fprintf(fp,"%ld",(long int)ws[i]); 
               ++tc; 
             }
           }
