@@ -161,6 +161,7 @@ ConcreteType( Scn_Stream_IMP )
   symbol     cIndentSym;
   symbol     cDedentSym;
   /* pattern token */
+  short      cPatCnt;
   short      cPatTok;
   short      cPatGrp;
   symbol     cPatSym;
@@ -706,7 +707,7 @@ static symbol Stream_init_Pattern_sym(Scn_Stream_IMP s, c_string p, c_bool seq)
     Sink_printf(snk,"%c",(c_byte)c1);
     if( *(p+i+3) == '.' )
     {
-      assert0(i + 9 < len,"invalid start pattern or quotient token ID");
+      assert0(i + 9 <= len,"invalid start pattern or quotient token ID");
       i += 6;
       buf[0] = p[i];
       buf[1] = p[i+1];
@@ -907,6 +908,7 @@ static Scn_Stream Stream_bgn_intern(Scn_T scn, Scn_Stream_Itr itr, c_bool top)
   s->cIndentStack = (ROW(int))NULL;
   s->cIndentSym   = (symbol)NULL;
   s->cDedentSym   = (symbol)NULL;
+  s->cPatCnt      = 0;
   s->cPatTok      = -1;
   s->cPatGrp      = -1;
   s->cPatSym      = (symbol)NULL;
@@ -1472,6 +1474,57 @@ void Stream_defTokId(Scn_Stream t, string Name, short tid)
   bug2(False,"\'Scn_defTokId(\"%s\",%d)\': Token not seen",Name,tid);
 }
 
+c_bool Stream_hasTokId(Scn_Stream t, string Name)
+/* whether 'Name' is a token in scan stream 't' */
+{ int cnt, i, j, g = -1; Scn_Stream_IMP s = (Scn_Stream_IMP)t;
+  size_t len = strlen(Name);
+  if( s->cScanner->Groups == 0 )
+  {
+    for (i = 1; i < s->cScanner->Tokens; i++)
+      if (
+          !strncmp(Name,s->cScanner->TokId[i],len) && 
+          (s->cScanner->TokId[i][len] == '\0' ||
+           s->cScanner->TokId[i][len] == SCN_SEP_TOK_ID_PATTERN))
+      {
+        return C_True;
+      }
+  }
+  else
+  { Scn_Stream_IMP x = (Scn_Stream_IMP)Stream_current(t);
+    if( x->cEmbeds == (ROW(Any_T))NULL || x->Group < 0 )
+    {
+      i = 0; cnt = s->cScanner->Groups;
+      if( (g=s->Group) >= 0 )
+      {
+        for (j = 1; j < s->cScanner->GrpScn[g]->Tokens; j++)
+          if (!strncmp(Name,s->cScanner->GrpScn[g]->TokId[j],len) && 
+              (s->cScanner->GrpScn[g]->TokId[j][len] == '\0' ||
+               s->cScanner->GrpScn[g]->TokId[j][len] == SCN_SEP_TOK_ID_PATTERN))
+          {
+            return C_True;
+          }
+      }
+    }
+    else
+    {
+      i = x->Group; cnt = x->Group + 1;
+    }
+    for ( ; i < cnt; i++)
+    {
+      if( i == g ) continue;
+      for (j = 1; j < s->cScanner->GrpScn[i]->Tokens; j++)
+        if (
+            !strncmp(Name,s->cScanner->GrpScn[i]->TokId[j],len) && 
+            (s->cScanner->GrpScn[i]->TokId[j][len] == '\0' ||
+             s->cScanner->GrpScn[i]->TokId[j][len] == SCN_SEP_TOK_ID_PATTERN))
+        {
+          return C_True;
+        }
+    }
+  }
+  return C_False;
+}
+
 static void setIndTokKey(Scn_Stream t, symbol keysym)
 { Scn_Stream_IMP s = (Scn_Stream_IMP)t;
   long           klen, dlen, ilen;
@@ -1522,6 +1575,17 @@ static void setIndTokKey(Scn_Stream t, symbol keysym)
   }
 }
 
+c_bool Stream_defDynKeyId(Scn_Stream t, symbol keysym, short tid)
+/* defines 'tid' as number for dynamic keyword 'keysym' in scan stream 't' */
+{ Scn_Stream_IMP s = (Scn_Stream_IMP)t;
+  if( !MAP_defined(s->cdefkey,keysym) )
+  {
+    MAP_dfndom(s->cdefkey,keysym,(long)tid);
+    return C_True;
+  }
+  return C_False;
+}
+
 void Stream_defKeyId(Scn_Stream t, string Text, short tid)
 /* defines 'tid' as number for keyword 'Text' in scan stream 't' */
 { Scn_Stream_IMP s      = (Scn_Stream_IMP)t;
@@ -1936,9 +2000,11 @@ static void Tok_pattern(Scn_Stream_IMP t)
       t->cPatGrp = s->Group;
     /* get pattern set */
     pat = symbolToString(MAP_apply(symbol,t->cPatMap,idx));
+    t->cPatCnt = 0;
     /* get pattern */
     if( *pat != '\0' )
     {
+      if( pat[1] == '\0' ) t->cPatCnt = 1;
       snk = Sink_open();
       if( s->wc2mb == (string (*)(wc_string wc))NULL )
       { 
@@ -1988,12 +2054,16 @@ static void Tok_pattern(Scn_Stream_IMP t)
     else
     if( s->wc2mb == (string (*)(wc_string wc))NULL )
     {
-      if( s->cC_eof == 0 && strstr(s->cBuf,pat) != (c_string)NULL )
-      { /* single byte text mode, pattern found */
-        s->cTok = t->cPatTok;
-        if( s->cScanner->Groups > 0 )
-          Stream_switch_group(t,t->cPatGrp,C_True);
-        t->cPatSym = (symbol)NULL;
+      c_string p = NULL;
+      if( s->cC_eof == 0 && (p=strstr(s->cBuf,pat)) != (c_string)NULL )
+      { 
+        if( t->cPatCnt != 1 || *(p+strlen(pat)) != pat[0] )
+        { /* single byte text mode, pattern found */
+          s->cTok = t->cPatTok;
+          if( s->cScanner->Groups > 0 )
+            Stream_switch_group(t,t->cPatGrp,C_True);
+          t->cPatSym = (symbol)NULL;
+        }
       }
       else
       if( s->cC_eof < 0 ) /* binary mode */
@@ -2014,13 +2084,16 @@ static void Tok_pattern(Scn_Stream_IMP t)
               if( flg && s->cBuf[j] != pat[0] ) i=j;
               else flg = C_False;
             }
-            if( len == k ) /* pattern found */
+            if( len == k ) 
             {
-              s->cTok = t->cPatTok;
-              if( s->cScanner->Groups > 0 )
-                Stream_switch_group(t,t->cPatGrp,C_True);
-              t->cPatSym = (symbol)NULL;
-              break;
+              if( t->cPatCnt != 1 || j >= s->cLen || s->cBuf[j] != pat[0] )
+              { /* pattern found */
+                s->cTok = t->cPatTok;
+                if( s->cScanner->Groups > 0 )
+                  Stream_switch_group(t,t->cPatGrp,C_True);
+                t->cPatSym = (symbol)NULL;
+                break;
+              }
             }
           }
         }
@@ -2045,13 +2118,16 @@ static void Tok_pattern(Scn_Stream_IMP t)
             if( flg && c != pat[0] ) i=j;
             else flg = C_False;
           }
-          if( len == k ) /* pattern found */
+          if( len == k ) 
           {
-            s->cTok = t->cPatTok;
-            if( s->cScanner->Groups > 0 )
-              Stream_switch_group(t,t->cPatGrp,C_True);
-            t->cPatSym = (symbol)NULL;
-            break;
+            if( t->cPatCnt != 1 || j >= s->cLen || ((char)s->cWBuf[j]) != pat[0] )
+            { /* pattern found */
+              s->cTok = t->cPatTok;
+              if( s->cScanner->Groups > 0 )
+                Stream_switch_group(t,t->cPatGrp,C_True);
+              t->cPatSym = (symbol)NULL;
+              break;
+            }
           }
         }
       }
@@ -2541,9 +2617,13 @@ short Stream_ctid(Scn_Stream t)
       return x->cdeftok[0];
   }
   else
+  {
+    if( s->cScanner->Groups > 0 && !strncmp("tok_",s->cScanner->GrpScn[s->Group]->Name,4) )
+      return x->cdeftok[s->cTok];
     return MAP_defined(x->cdefkey,s->cSym)
            ? MAP_apply_short(x->cdefkey,s->cSym)
            : x->cdeftok[s->cTok];
+  }
 }
 
 short Stream_ctid_nokey(Scn_Stream t)
