@@ -435,8 +435,8 @@ static void Scn_C_SourceScanner(FILE* fp, Scn_T x)
   fprintf(fp,"/* the scanner structure */\n");
   fprintf(fp,"{\n");
   fprintf(fp,"  \"%s\", /* Name    */\n",scn->Name   );
-  fprintf(fp,"  %2d,%*s /* States  */\n",scn->States , strlen(scn->Name), "");
-  fprintf(fp,"  %2d,%*s /* Tokens  */\n",scn->Tokens , strlen(scn->Name), "");
+  fprintf(fp,"  %2d,%*s /* States  */\n",scn->States , (int)strlen(scn->Name), "");
+  fprintf(fp,"  %2d,%*s /* Tokens  */\n",scn->Tokens , (int)strlen(scn->Name), "");
   if( scn->Groups == 0 )
   {
     fprintf(fp,"  %sStaEdg,\n",scn->Name);
@@ -455,7 +455,7 @@ static void Scn_C_SourceScanner(FILE* fp, Scn_T x)
     fprintf(fp,"  (c_string*)NULL,\n");
     fprintf(fp,"  (c_byte*)NULL,\n");
   }
-  fprintf(fp,"  %2d,%*s /* Groups  */\n",scn->Groups , strlen(scn->Name), "");
+  fprintf(fp,"  %2d,%*s /* Groups  */\n",scn->Groups , (int)strlen(scn->Name), "");
   if( scn->Groups == 0 )
   {
     fprintf(fp,"  (scn_t*)NULL,\n");
