@@ -463,8 +463,9 @@ static symbol SPP_applyParameter(SPP_T pPP, symbol pTokVal, symbol* pMacNam)
   else return (symbol)NULL;
 }
 
-static symbol SPP_applyMacro(SPP_T pPP, symbol pTokVal)
+static symbol SPP_applyMacro(SPP_T pPP, symbol pTokVal, symbol* pMacNam)
 { ROW(symbol) pMacDfnRow = MAP_apply(ROW(symbol),pPP->pMacDfnMap,pTokVal), pTmpRow;
+  *pMacNam = pTokVal;
   if( pPP->pCurMacRow == (ROW(symbol))NULL )
   {
     if( OT_CNT(pMacDfnRow) == 1 ) return OT_GET(symbol,pMacDfnRow,0);
@@ -478,9 +479,9 @@ static symbol SPP_applyMacro(SPP_T pPP, symbol pTokVal)
     }
   }
   else
-  { symbol pMacNam;
+  { 
     if( OT_CNT(pMacDfnRow) == 1 ) 
-      return SPP_applyParameter(pPP,OT_GET(symbol,pMacDfnRow,0),&pMacNam);
+      return SPP_applyParameter(pPP,OT_GET(symbol,pMacDfnRow,0),pMacNam);
     else
     {
       pTmpRow = OT_CREATE_ADT(symbol);
@@ -570,12 +571,12 @@ int SPP_premac
     {
       if( lCnt == 0 ) OT_PUSH(SPP_COND_ERROR,pPP->pCondRow);
       else
-      {
+      { long dmy = 0;
         if( OT_TOP(long,pPP->pCondRow) == SPP_COND_SKIP )
-          OT_UPD(long,pPP->pCondRow,lCnt-1,SPP_COND_SCAN);
+          dmy = OT_UPD(long,pPP->pCondRow,lCnt-1,SPP_COND_SCAN);
         else 
         if( OT_TOP(long,pPP->pCondRow) == SPP_COND_SCAN )
-          OT_UPD(long,pPP->pCondRow,lCnt-1,SPP_COND_SKIP);
+          dmy = OT_UPD(long,pPP->pCondRow,lCnt-1,SPP_COND_SKIP);
       }
     }
     else
@@ -631,9 +632,9 @@ int SPP_premac
       if( !strcmp(cTokNam,SPP_PREPAR(pPP,SPP_TOK_IDE)) && 
           MAP_defined(pPP->pMacDfnMap,pLowValSym)       )
       { 
-        *cMacVal = SPP_applyMacro(pPP,pLowValSym);
+        *cMacVal = SPP_applyMacro(pPP,pLowValSym,&pMacNam);
         return ( *cMacVal != (symbol)NULL )
-               ? SPP_prepare_rescan(pPP,pStream,SCN_FLG_RescanString,pLowValSym,cMacVal) 
+               ? SPP_prepare_rescan(pPP,pStream,SCN_FLG_RescanString,pMacNam,cMacVal) 
                : SCN_FLG_RescanNone;
       }
       else
