@@ -215,10 +215,27 @@ Any_T* MakeArgLst(va_list args, int fixed_cnt, ...)
 
 /*I------------- Workaround for missing C library functions ----------------- */
 
+wc_string wcsstr_aux(wc_string s1, wc_string s2)
+/* workaround for 'wcsstr' */
+{ wc_string res = (wc_string)NULL, s = s1;
+  if( s1 != (wc_string)NULL && s2 != (wc_string)NULL )
+  { int l2 = WCStrLen(s2)*sizeof(wc_char);
+    while( *s != WCHAR_LITERAL('\0') )
+    {
+      if( !memcmp(s,s2,l2) )
+      {
+        res = s; break;
+      }
+      else s += 1;
+    }
+  }
+  return res;
+}
+
 c_string strstr_aux(c_string s1, c_string s2)
 /* workaround for 'strstr' */
 { c_string res = (c_string)NULL, s = s1;
-  if( s1 != (c_string)NULL || s2 != (c_string)NULL )
+  if( s1 != (c_string)NULL && s2 != (c_string)NULL )
   { int l2 = strlen(s2);
     while( *s != '\0' )
     {
@@ -232,6 +249,23 @@ c_string strstr_aux(c_string s1, c_string s2)
   return res;
 }
 
+wc_string wcschr_aux(wc_string s, wc_char c)
+/* workaround for 'wcschr' */
+{ wc_string res = (wc_string)NULL, t = s;
+  if( s != (wc_string)NULL )
+  {
+    while( *t != WCHAR_LITERAL('\0') )
+    { 
+      if( (*t) == c )
+      {
+        res = t; break;
+      }
+      else t += 1;
+    }
+  }
+  return res;
+}
+
 c_string strchr_aux(c_string s, int c)
 /* workaround for 'strchr' */
 { c_string res = (c_string)NULL, t = s;
@@ -249,6 +283,27 @@ c_string strchr_aux(c_string s, int c)
   return res;
 }
 
+wc_string wcsrchr_aux(wc_string s, wc_char c)
+/* workaround for 'wcsrchr' */
+{ wc_string res = (wc_string)NULL, t;
+  if( s != (wc_string)NULL )
+  { int l = WCStrLen(s);
+    t = s + l;
+    while( l >= 0 )
+    { 
+      if( (*t) == c )
+      {
+        res = t; break;
+      }
+      else
+      {
+        t -= 1; l -= 1;
+      }
+    }
+  }
+  return res;
+}
+
 c_string strrchr_aux(c_string s, int c)
 /* workaround for 'strrchr' */
 { c_string res = (c_string)NULL, t;
