@@ -404,14 +404,14 @@ namespace styx
     else
       cout << "\nDerivation Tree : ";
     cout << "\n";
-    visit(printNode);
+    this->visit(printNode);
     cout << "\n";
   }
 
   template <class TC> 
   basic_string<TC> TStyxParseTree<TC>::asString()
   { T_value2string value2string;
-    visit(value2string);
+    this->visit(value2string);
     return value2string.treestring;
   }
 
@@ -510,7 +510,7 @@ namespace styx
     node.col  = Token.Column;
     if( conv && !convert(node.name[0],node.val) )
     {
-      error("conversion of token '" + node.name[0] + "' failed");
+      this->error("conversion of token '" + node.name[0] + "' failed");
       return false;
     }
     T_Tree* tree = T_Tree::create(node);
