@@ -358,6 +358,7 @@ namespace styx
         pattern token specification and attributes
     */
     //@{
+    short         cPatCnt;  ///< number of pattern characters
     short         cPatTok;  ///< current start pattern token
     short         cPatGrp;  ///< current start pattern group
     string        cPatSym;  ///< current end pattern matchcode
@@ -641,6 +642,9 @@ namespace styx
                          /// @param Token internal token name
                          /// @return external token name
     virtual string       externalTokenID(const string& Token);
+                         /// get current group identifier or ""
+                         /// @return current group name or ""
+    virtual string       currentGroupID();
                          /// current token is not case sensitive ?
                          /// @return true for a case insensitive token
     virtual bool         ignoreCase();
