@@ -318,6 +318,7 @@ namespace styx
         pattern token specification and attributes
     */
     //@{
+    protected short      cPatCnt;  //!< number of pattern characters
     protected short      cPatTok;  //!< current start pattern token
     protected short      cPatGrp;  //!< current start pattern group
     protected string     cPatSym;  //!< current end pattern matchcode
@@ -683,7 +684,7 @@ namespace styx
         result += (char)c1;
         if( p[i+3] == '.' )
         {
-          if( i+9 >= len )
+          if( i+9 > len )
           {
             error("invalid start pattern or quotient token ID");
             return false;
@@ -1149,6 +1150,7 @@ namespace styx
           cPatGrp = Group;
         /* get pattern set */
         string pat = (string)cPatMap[idx];
+        cPatCnt = (short)pat.Length;
         /* get pattern */
         long i;
         for( i=0; i < buffer.Length; ++i )
@@ -1172,10 +1174,15 @@ namespace styx
       { /* end pattern token, try to match pattern */
         long pos = buffer.IndexOf(cPatSym);
         if( pos >= 0 && pos < buffer.Length )
-        { /* pattern found */
-          cTok = cPatTok; cPatSym = "";
-          if( GrpScn.Count > 0 && !switchGroup(cPatGrp,true) )
-            return false;
+        { 
+          if( cPatCnt != 1 || pos + cPatSym.Length >= buffer.Length ||
+              buffer[(int)(pos+cPatSym.Length)] != cPatSym[0] )
+          {
+            /* pattern found */
+            cTok = cPatTok; cPatSym = "";
+            if( GrpScn.Count > 0 && !switchGroup(cPatGrp,true) )
+              return false;
+          }
         }
       }
       else cTok = 0; /* error */
@@ -1498,6 +1505,7 @@ namespace styx
       nLine   = 1;
       nCol    = 1;
       cTok    = 0;
+      cPatCnt = 0;
       cPatTok = cPatGrp = -1;
       cPatSym = "";
       bbuffer.Clear();
