@@ -26,24 +26,24 @@
   classes are created.
 
   A) well-formed productions:
-  1. let X :nil  :            <0 members>
-  2. let X :cons : Y Z        <2 members: Y = member && Z = nonterminal>
-  3. let X :ign#*: Y          <1 nonterminal>
-  4. let X :name : X1 .. Xn   <n >= 0 && name =/= { ign#, nil, cons }>
+  1. let X :nil#* :            <0 members>
+  2. let X :cons#*: Y Z        <2 members: Y = member && Z = nonterminal>
+  3. let X :ign#+ : Y          <1 nonterminal>
+  4. let X :name  : X1 .. Xn   <n >= 0 && name =/= { ign#+, nil#*, cons#* }>
 
   Extension for options (styx version >= 1):
 
   5. let X :none :            <0 members>
   6. let X :some : Y          <1 member>
-  7. let X :name : X1 .. Xn   <n >= 0 && name =/= { ign#, nil, cons, none, some }>
+  7. let X :name : X1 .. Xn   <n >= 0 && name =/= { ign#+, nil#*, cons#*, none, some }>
   
 
   B) construction of the token/nonterminal classes:
   1. X <=> X                          reflexiv 
   2. X <=> Y --> Y <=> X              symmetric
   3. X <=> Y && Y <=> Z --> X <=> Z   transitiv
-  4. let X :ign1: Y   --> X <=> Y
-  5. let X :cons: Y Z --> X <=> Z  
+  4. let X :ign#+: Y   --> X <=> Y
+  5. let X :cons#*: Y Z --> X <=> Z  
   6. X <=> Y && let X :idx: X1 .. Xn && let Y :idy: Y1 .. Ym && idx = idy
      --> n = m && forall i, 1 <= i <= n: Type(Xi) = Type(Yi) && Xi <=> Yi,
                                          where Type(Z) = { token, nonterminal }
@@ -59,14 +59,14 @@
   D) correctness:
   1. X <=> Y --> Type(X) = Type(Y), where Type(Z) = { token, nonterminal }
   2. let X^ :id: a && let X^ :id: b --> a <=> b
-  3. let X^ :nil: a || let X^ :cons: b
-     --> not exists P: P = let X^ :id: c && id =/= { ign#, nil, cons }
+  3. let X^ :nil#*: a || let X^ :cons#*: b
+     --> not exists P: P = let X^ :id: c && id =/= { ign#+, nil#*, cons#* }
   [ 1,2: checked during construction ]
 
   Extension for options (styx version >= 1):
 
   4. let X^ :none: a || let X^ :some: b
-     --> not exists P: P = let X^ :id: c && id =/= { ign#, none, some }
+     --> not exists P: P = let X^ :id: c && id =/= { ign#+, none, some }
   5. let X^ :none: a 
      --> exists P: P = let X^ :some: b
   6. let X^ :some: a 
@@ -108,6 +108,7 @@ typedef struct _PSDFN {
 /* production symbol ( definition interface ) */
   bool istoken; /* symbol is a token */
   int  symbol;  /* symbol            */
+  int  dsymbol; /* dynamic symbol    */
   long sRow;    /* line position     */
   long sCol;    /* col position      */
 } PSDFN;
@@ -118,8 +119,17 @@ typedef struct _PRDFN {
   int    method;  /* reduction method */
   int    pid;     /* nonterminal      */
   OT_Tab psymbol; /* symbols          */
+  int    idx;     /* position index   */
 } PRDFN;
 
+typedef struct _CRULE {
+/* conflict rule ( definition interface ) */
+  int    StateIdx; /* state index         */
+  int    StateSym; /* state symbol        */
+  int    TokenIdx; /* token index         */
+  OT_Tab ProdIdx;  /* production indexes  */
+} CRULE;
+
 typedef struct _KFGDFN {
 /* context free grammar ( definition interface ) */
   string language; /* language            */
@@ -132,6 +142,7 @@ typedef struct _KFGDFN {
   OT_Tab TokKind;  /* token kind          */
   OT_Tab ErrorNt;  /* error recovery nt's */
   OT_Tab Prod;     /* productions         */
+  OT_Tab Conflict; /* productions         */
 } KFGDFN;
 
 typedef struct _KFGNT {
@@ -168,6 +179,7 @@ typedef struct _PrsGen_T {
   int      MaxSymCnt;    /* max. Anzahl Produktionssymbole      */
   int      MaxSymNamLen; /* max. Laenge der Symbol Namen        */
   int      conflictCnt;  /* Anzahl Konflikte                    */
+  int      cruleCnt;     /* Anzahl geregelter Konflikte         */
   int      version;      /* styx version                        */
   
   OT_Tab*  NtEquiv;      /* Equivalence Tables of Nonterminals  */
@@ -175,6 +187,7 @@ typedef struct _PrsGen_T {
   KFGHEAD* Kfg;          /* Grammatik-Kopfdaten                 */
   KFGNT*   NonTermTab;   /* Nonterminals der Grammatik          */
   KFGPROD* ProdTab;      /* Produktionen der Grammatik          */
+  OT_Tab   ProdIdx;      /* Produktionsindex neu -> alt         */
   OT_Tab   GoToKern;     /* Kerne der Folgezustaende            */
                          /* ( Tabelle von Kernelement-Listen )  */
   OT_Tab   KernTab;      /* Indizes Kernelemente                */
@@ -233,12 +246,17 @@ typedef struct _PrsGen_T {
 #define INS_PROD(p,t)     OT_T_INS(t,p)
 #define GET_PROD(t,i)     OT_GET(PRDFN*,t,i)
 #define SRT_PRODS(t)      OT_SORT(t,cmpProd)
+#define SRT_PRODS_2(t)    OT_SORT(t,cmpProd2)
 #define FND_PROD(t,ti,k)  OT_B_FIND(t,ti,(k),cmpProd)
 
 #define NEW_STATETAB      OT_CREATE(PSTATE,cpyState,delState,primEqual)
 #define INS_STATE(s,t)    OT_T_INS(t,s)
 #define GET_STATE(t,i)    OT_GET(PSTATE*,t,i)
 
+#define NEW_CONFLICTTAB   OT_CREATE(CRULE,cpyConflict,delConflict,primEqual)
+#define INS_CONFLICT(c,t) OT_T_INS(t,c)
+#define GET_CONFLICT(t,i) OT_GET(CRULE*,t,i)
+
 #define NEW_KLISTTAB      OT_CREATE(OL_Lst,primCopy,OL_delL,OL_equal)
 #define INS_KLIST(l,t)    OT_T_INS(t,l)
 #define GET_KLIST(t,i)    OT_GET(OL_Lst,t,i)
@@ -309,17 +327,37 @@ static OT_Obj cpyProd(OT_Obj prod)
 {
   return( cpyTObj(prod,sizeof(PRDFN)) );
 }
-
+
 static OT_Obj cpyState(OT_Obj state)
 /* copy state */
 {
   return( cpyTObj(state,sizeof(PSTATE)) );
 }
 
+static OT_Obj cpyConflict(OT_Obj conflict)
+/* copy conflict */
+{
+  return( cpyTObj(conflict,sizeof(CRULE)) );
+}
+
 static int cmpProd(OT_Obj left, OT_Obj right)
 /* left key - right key */
 {
-  return( ((PRDFN*)left)->pid - ((PRDFN*)right)->pid );
+  return ( ((PRDFN*)left)->pid - ((PRDFN*)right)->pid );
+}
+
+static int cmpProd2(OT_Obj left, OT_Obj right)
+/* left key - right key */
+{
+  int res = ( ((PRDFN*)left)->pid - ((PRDFN*)right)->pid );
+  if( res != 0 ) return res;
+  return ( ((PRDFN*)left)->idx - ((PRDFN*)right)->idx );
+}
+
+static int cmpElements(OT_Obj left, OT_Obj right)
+/* left element - right element */
+{
+  return( intCAST(left) - intCAST(right) );
 }
 
 static int* cpyInt(OT_Obj obj)
@@ -580,7 +618,9 @@ static bool setEquivProdNts(PrsGen_T* PrsGen, int ntidx1, int ntidx2)
         for( j =  FIRSTNTPROD(NTSYMBOL(ntidx2)); 
              j <= LASTNTPROD(NTSYMBOL(ntidx2)); ++j )
         { KFGPROD pi = PrsGen->ProdTab[i], pj = PrsGen->ProdTab[j];
-          if( ! strcmp(pi.pname,pj.pname) ) 
+          if( ( !strcmp(pi.pname,pj.pname) ) || 
+              ( nilProd(pi.pname) && nilProd(pj.pname) ) ||
+              ( consProd(pi.pname) && consProd(pj.pname) ) )
           { int k = nextProdMember(PrsGen,&pi,0), 
                 l = nextProdMember(PrsGen,&pj,0);
             c_bug
@@ -600,7 +640,9 @@ static bool setEquivProdNts(PrsGen_T* PrsGen, int ntidx1, int ntidx2)
                 PrsGen->Kfg->SNames[pj.id],pj.pname
               );
               if( CFG_NTM(typ) && setEquivNts(PrsGen,NTIDX(ksym),NTIDX(lsym)) ) 
+              {
                 change = True;
+              }
               k = nextProdMember(PrsGen,&pi,k+1); 
               l = nextProdMember(PrsGen,&pj,l+1);
             }
@@ -640,7 +682,7 @@ static void pass2NtPartition(PrsGen_T* PrsGen)
     for( i=0; i < PrsGen->Kfg->NtCnt; ++i ) 
     { OT_Tab cls; int cnt, j, k;
       if( i == NTCLASS(i) && ( cnt = OT_CNT(cls = NTEQUIV(i)) ) > 1 )
-        for( j=0; j < cnt; ++j ) for( k=j+1; k < cnt; ++k )
+        for( j=0; j < cnt; ++j ) for( k=j/*+1*/; k < cnt; ++k )
           if( setEquivProdNts(PrsGen,OT_GET(int,cls,j),OT_GET(int,cls,k)) )
             change = True;
     }
@@ -689,6 +731,13 @@ static void delState(StdCPtr StateEl)
   FreeMem((PSTATE*)StateEl);
 }
 
+static void delConflict(StdCPtr ConflictEl)
+/* Loeschen einer Produktion */
+{
+  OT_DEL_T(((CRULE*)ConflictEl)->ProdIdx);
+  FreeMem((CRULE*)ConflictEl);
+}
+
 static void delCreateGlobals(PrsGen_T* PrsGen)
 /* Loeschen nicht mehr benoetigter Grammatik-Objekte */
 { int i;
@@ -708,6 +757,7 @@ static void delCreateGlobals(PrsGen_T* PrsGen)
   OT_DEL_T(PrsGen->KernTab);
   OT_DEL_T(PrsGen->GoToKern);
   OT_DEL_T(PrsGen->StateTab);
+  OT_DEL_T(PrsGen->ProdIdx);
 }
 
 /* ----------------------- Grammar Description ------------------------------ */
@@ -769,11 +819,12 @@ static void setKfgGlobals(PrsGen_T* PrsGen, PLR_Cfg Cfg)
 
 static void fillProdTabs(PrsGen_T* PrsGen, PLR_Cfg Cfg)
 /* Initialisierung der Grammatik-Produktionsdaten, Nonterminal Partition */
-{ OT_Tab PIdx; int i, j; bool change = False;
+{ OT_Tab PIdx, PIdx2; int i, j; bool change = False;
 
   BUG_RNG1(OT_CNT(PLR_C_IMP(Cfg)->Prod),MAX_OBJECTS);
   PrsGen->ProdCnt    = (int)OT_CNT(PLR_C_IMP(Cfg)->Prod)+PrsGen->Kfg->StartCnt;
   PIdx               = SRT_PRODS(PLR_C_IMP(Cfg)->Prod);
+  PIdx2              = SRT_PRODS_2(PLR_C_IMP(Cfg)->Prod);
   PrsGen->NonTermTab = (KFGNT*)NewMem(NONTERMCNT*sizeof(KFGNT));
   for( i=0; i < NONTERMCNT; ++i )
   {
@@ -800,19 +851,23 @@ static void fillProdTabs(PrsGen_T* PrsGen, PLR_Cfg Cfg)
     PrsGen->NonTermTab[i].first  = BS_create(TERMCNT);
   }
   PrsGen->ProdTab   = (KFGPROD*)NewMem(PrsGen->ProdCnt*sizeof(KFGPROD));
+  PrsGen->ProdIdx   = NEW_INTTAB;
   PrsGen->MaxSymCnt = 1;
   for( i=0; i < PrsGen->ProdCnt; ++i )
   {
     if( i < OT_CNT(PLR_C_IMP(Cfg)->Prod) )
-    { PRDFN* prod = GET_PROD(PLR_C_IMP(Cfg)->Prod,GET_INTTE(PIdx,i));
+    { PRDFN* prod = GET_PROD(PLR_C_IMP(Cfg)->Prod,GET_INTTE(PIdx2,i));
 
       BUG_RNG0(OT_CNT(prod->psymbol),MAX_OBJECTS);
+      INS_INTTE((int)prod->idx,PrsGen->ProdIdx);
       PrsGen->ProdTab[i].pname  = StrCopy(prod->pname);
       PrsGen->ProdTab[i].id     = PrsGen->Kfg->TkCnt + prod->pid;
       PrsGen->ProdTab[i].method = prod->method;
       PrsGen->ProdTab[i].symcnt = (int)OT_CNT(prod->psymbol);
       PrsGen->MaxSymCnt = ( PrsGen->ProdTab[i].symcnt > PrsGen->MaxSymCnt ) ?
                           PrsGen->ProdTab[i].symcnt : PrsGen->MaxSymCnt;
+      PrsGen->ProdTab[i].dsymidx = -1;
+      PrsGen->ProdTab[i].dsymsym = -1;
       if( PrsGen->ProdTab[i].symcnt )
       { long r0 = GET_PSYM(prod->psymbol,0)->sRow,
              c0 = GET_PSYM(prod->psymbol,0)->sCol;
@@ -832,6 +887,11 @@ static void fillProdTabs(PrsGen_T* PrsGen, PLR_Cfg Cfg)
             PrsGen->ProdTab[i].symfrms[j] = (int)(( cr > pr ) ? -cc : cc);
           }
           else PrsGen->ProdTab[i].symfrms[j] = 0;
+          if( GET_PSYM(prod->psymbol,j)->dsymbol >= 0 )
+          {
+            PrsGen->ProdTab[i].dsymidx = j;
+            PrsGen->ProdTab[i].dsymsym = GET_PSYM(prod->psymbol,j)->dsymbol;
+          }
         }
       }
       else PrsGen->ProdTab[i].symbols = PrsGen->ProdTab[i].symfrms = (int*)NULL;
@@ -850,9 +910,12 @@ static void fillProdTabs(PrsGen_T* PrsGen, PLR_Cfg Cfg)
       PrsGen->ProdTab[i].pname      = (string)NewMem(7+strlen(StNt));
       sprintf(PrsGen->ProdTab[i].pname,"Start_%s",StNt);
       PrsGen->ProdTab[i].symfrms[0] = 0;
+      PrsGen->ProdTab[i].dsymidx = -1;
+      PrsGen->ProdTab[i].dsymsym = -1;
     }
   }
   OT_DEL_T(PIdx);
+  OT_DEL_T(PIdx2);
   if( change ) pass2NtPartition(PrsGen);
 }
 
@@ -1560,7 +1623,7 @@ static void fillActExpLst
   }
 }
 
-static void fillActTabs(PrsGen_T* PrsGen, OT_Tab ActDft, OT_Tab ActExp)
+static void fillActTabs_OLD(PrsGen_T* PrsGen, OT_Tab ActDft, OT_Tab ActExp)
 /* Bestimmung der Default/Ausnahme-Aktionstabellen                          */
 /* ActDft : 1 Eintrag / Zustand -- ACT_ACCEPT, ACT_ERROR, Red.Nr ( >= 1 ),  */
 /*                                 negativer Index des 1. ActExp-Eintrags   */
@@ -1605,7 +1668,121 @@ static void fillActTabs(PrsGen_T* PrsGen, OT_Tab ActDft, OT_Tab ActExp)
   }
 }
 
-static PLR_Tab fillParseTab(PrsGen_T* PrsGen)
+static void fillActTabs(PrsGen_T* PrsGen, PLR_Cfg Cfg, OT_Tab ActDft, OT_Tab ActExp)
+/* Bestimmung der Default/Ausnahme-Aktionstabellen                           */
+/* ActDft : 1 Eintrag / Zustand -- ACT_ACCEPT, ACT_ERROR, Red.Nr ( >= 1 ),   */
+/*                                 negativer Index des 1. ActExp-Eintrags    */
+/* ActExp : siehe fillActExpLst, sortierte Reduktionselemente / Produktionen */
+{ INT i, j, k, l;
+
+  for( i=0; i < OT_CNT(PrsGen->StateTab); ++i )
+  { PSTATE* curr = GET_STATE(PrsGen->StateTab,i);
+    int lalrel = ACT_ERROR, FstRedElement, RedElement, pos;
+    int FstPos = nextRedElement(PrsGen,curr,&FstRedElement,0);
+
+    if( ! FstPos ) /* Default-Aktion: ACT_ERROR */
+      INS_INTTE(lalrel,ActDft);
+    else
+    {
+      pos = nextRedElement(PrsGen,curr,&RedElement,FstPos);
+      if( ! pos ) /* Default-Aktion: ACT_ACCEPT/Reduktion */
+      { /* veraenderte Bedingung fuer Fehlerbehandlung */
+        lalrel = RedAction(PrsGen,FstRedElement); 
+        INS_INTTE(lalrel,ActDft);
+      }
+      else /* Ausnahme-Aktionen: ACT_ACCEPT/Reduktion */
+      { bool negFlg = ( ! OT_CNT(ActExp) || 
+                        GET_INTTE(ActExp,OT_CNT(ActExp)-1) < 0 )
+                      ? False : True;
+        OT_Tab redpos = NEW_INTTAB;
+        OT_Tab redelm = NEW_INTTAB;
+        OT_Tab redidx = (OT_Tab)NULL;
+        OT_Tab redcl  = NEW_LOOKTAB;
+        BS_Set cl1, cl2;
+        int cntConflicts = OT_CNT(PLR_C_IMP(Cfg)->Conflict);
+
+        lalrel = (int)(-OT_CNT(ActExp)); INS_INTTE(lalrel,ActDft);
+
+        INS_INTTE(FstPos,redpos);
+        INS_INTTE(FstRedElement,redelm);
+        if( cntConflicts > 0 )
+        {
+          cl1 = GET_LOOK(curr->looks,FstPos-1);
+          cl2 = BS_create(BS_card(cl1));
+          cl2 = BS_copy(cl2,cl1);
+          INS_LOOK(cl2,redcl);
+        }
+        while( pos > 0 )
+        { 
+          INS_INTTE(pos,redpos);
+          INS_INTTE(RedElement,redelm);
+          if( cntConflicts > 0 )
+          {
+            cl1 = GET_LOOK(curr->looks,pos-1);
+            cl2 = BS_create(BS_card(cl1));
+            cl2 = BS_copy(cl2,cl1);
+            INS_LOOK(cl2,redcl);
+          }
+          pos = nextRedElement(PrsGen,curr,&RedElement,pos);
+        }
+        redidx = OT_SORT(redelm,cmpElements);
+
+        for( j=0; j < cntConflicts; ++j )
+        {
+          CRULE* conflict = GET_CONFLICT(PLR_C_IMP(Cfg)->Conflict,j);
+          if( ( conflict->StateIdx == i || 
+              ( curr->symbol >= 0 && curr->symbol == conflict->StateSym ) ) &&
+              OT_CNT(conflict->ProdIdx) > 0 )
+          { c_bool found = C_False;
+            for( k=0; k < OT_CNT(conflict->ProdIdx); ++k )
+            { int cidx = GET_INTTE(conflict->ProdIdx,k);
+              for( l=0; l < OT_CNT(redelm); ++l )
+              { int ridx = GET_INTTE(redelm,l)-1;
+                if( ridx >= OT_CNT(PrsGen->ProdIdx) ) continue;
+                ridx = GET_INTTE(PrsGen->ProdIdx,ridx);
+                if( cidx == ridx )
+                { 
+                  cl1 = GET_LOOK(redcl,l);
+                  if( BS_member(conflict->TokenIdx,cl1) )
+                  {
+                    if( !found )
+                    {
+                      found = C_True;
+                    }
+                    else
+                    { 
+                      BS_delE(conflict->TokenIdx,cl1);
+                    }
+                  }
+                }
+              }
+            }
+          }
+        }
+
+        for( j=0; j < OT_CNT(redidx); ++j )
+        {
+          pos = GET_INTTE(redpos,GET_INTTE(redidx,j));
+          cl1 = cntConflicts > 0 
+                ? GET_LOOK(redcl,GET_INTTE(redidx,j)) 
+                : GET_LOOK(curr->looks,pos-1);
+          RedElement = GET_INTTE(redelm,GET_INTTE(redidx,j));
+          fillActExpLst
+          (
+            PrsGen,ActExp,RedElement,cl1,negFlg
+          );
+        }
+
+        OT_DEL_T(redpos);
+        OT_DEL_T(redelm);
+        OT_DEL_T(redidx);
+        OT_DEL_T(redcl);
+      }
+    }
+  }
+}
+
+static PLR_Tab fillParseTab(PrsGen_T* PrsGen, PLR_Cfg Cfg)
 /* Bestimmung der Analyse-Tabellen der Grammatik */
 { PARSETAB* PTab  = (PARSETAB*)NewMem(sizeof(PARSETAB));
   OT_Tab MstShift = NEW_INTTAB;
@@ -1635,7 +1812,7 @@ static PLR_Tab fillParseTab(PrsGen_T* PrsGen)
   PTab->tabs.GoToDft    = INTTE_ARRAY(GoToDft);
   OT_DEL_T(GoToDft);
 
-  fillActTabs(PrsGen,ActDft,ActExp);
+  fillActTabs(PrsGen,Cfg,ActDft,ActExp);
   BUG_VMIN(PTab->tabs.ActDftCnt = (int)OT_CNT(ActDft),0);
   PTab->tabs.ActDft    = INTTE_ARRAY(ActDft);
   OT_DEL_T(ActDft);
@@ -1703,7 +1880,7 @@ static void printFirstNtSets(PrsGen_T* PrsGen)
 
 static void ShiftConflicts
             (
-              PrsGen_T* PrsGen,BS_Set cl,OL_Lst states,bool printing
+              PrsGen_T* PrsGen, BS_Set cl,OL_Lst states,bool printing
             )
 /* prints shift-reduce conflicts for current kern element */
 { bool flag = False; INT i;
@@ -1734,12 +1911,14 @@ static void ShiftConflicts
 
 static void RedConflicts
             (
-              PrsGen_T* PrsGen,int clidx,BS_Set cl,
+              PrsGen_T* PrsGen, PLR_Cfg Cfg, 
+              int sidx, int pidx, int clidx, BS_Set cl,
               OT_Tab looks,OL_Lst readLst,bool printing
             )
 /* prints reduce-reduce conflicts for current kern element */
-{ bool flag = False; INT i;
+{ bool flag = False; INT i, j, k;
   char buf[STD_BUFFLEN+1];
+  PSTATE* curr = GET_STATE(PrsGen->StateTab,sidx);
   void (*prMsg)(c_string msg) = PrsGen->prMsg;
   if( prMsg == (void (*)(c_string msg))NULL ) prMsg = prMsg_stdout;
 
@@ -1748,9 +1927,10 @@ static void RedConflicts
 
     if( pos == PrsGen->MaxSymCnt + 1 &&
         ! BS_empty(BS_inter(PrsGen->TokenSet,cl,GET_LOOK(looks,i))) )
-    {
+    { int idx = PRODUCTION(fk) - 1, 
+          cnt = BS_cnt(PrsGen->TokenSet), ccnt = 0;
       if( printing )
-      { int idx = PRODUCTION(fk) - 1, id = PrsGen->ProdTab[idx].id; 
+      { int id = PrsGen->ProdTab[idx].id; 
         char c = ' ';
 
         if( id >= KFGSYMCNT )
@@ -1760,17 +1940,59 @@ static void RedConflicts
         sprintf(buf,"\n%*sReduce-Reduce-Conflict with Element: ",indent,"");
         (*prMsg)(buf);
         (*prMsg)(PrsGen->Kfg->SNames[id]);
-        sprintf(buf,"%c ( %3d )", c, pos);
+        sprintf(buf,"%c ( %3d ) :", c, pos);
         (*prMsg)(buf);
+        (*prMsg)(PrsGen->ProdTab[idx].pname);
+        (*prMsg)(": ");
         flag = True;
       }
+
+      if( idx < OT_CNT(PrsGen->ProdIdx) && pidx < OT_CNT(PrsGen->ProdIdx) )
+      { int idxold = GET_INTTE(PrsGen->ProdIdx,idx), 
+            pidxold = GET_INTTE(PrsGen->ProdIdx,pidx);
+        for( j=0; j < OT_CNT(PLR_C_IMP(Cfg)->Conflict); ++j )
+        {
+          CRULE* conflict = GET_CONFLICT(PLR_C_IMP(Cfg)->Conflict,j);
+          if( ( conflict->StateIdx == sidx || 
+              ( curr->symbol >= 0 && curr->symbol == conflict->StateSym ) ) &&
+              OT_CNT(conflict->ProdIdx) > 0 && 
+              BS_member(conflict->TokenIdx,PrsGen->TokenSet) )
+          { int rcnt = 0; 
+            for( k=0; k < OT_CNT(conflict->ProdIdx); ++k )
+            { int cidx = GET_INTTE(conflict->ProdIdx,k);
+              if( cidx == idxold || cidx == pidxold ) 
+              {
+                ++rcnt; 
+              }
+/*
+              if( rcnt == 1 ) 
+              {
+                ++ccnt;
+              }
+*/
+              if( rcnt >= 2 ) 
+              {
+                ++ccnt;
+                break;
+              }
+            }
+            if( cnt == ccnt ) 
+            {
+              if( printing ) (*prMsg)(" - solved by conflict rules");
+              ++PrsGen->cruleCnt;
+              break;
+            }
+          }
+        }
+      }
+
       ++PrsGen->conflictCnt;
     }
   }
   if( flag ) (*prMsg)("\n"); 
 }
 
-static void printStateTab(PrsGen_T* PrsGen)
+static void printStateTab(PrsGen_T* PrsGen, PLR_Cfg Cfg)
 /* prints state table and conflicts */
 { OL_Lst readLst = NEW_INTLIST; INT i, k; int cnt;
   char   buf[STD_BUFFLEN+1];
@@ -1806,10 +2028,14 @@ static void printStateTab(PrsGen_T* PrsGen)
       sprintf(buf,"\n%*s",indent+2,"");
       (*prMsg)(buf);
       (*prMsg)(PrsGen->Kfg->SNames[id]);
-      sprintf(buf,"%c ( %3d ) :: ",c,pos);
+      sprintf(buf,"%c ( %3d ) :",c,pos);
       (*prMsg)(buf);
+      (*prMsg)(PrsGen->ProdTab[idx].pname);
+      (*prMsg)(": ");
       if( c != '\'' )
-      { int fstcol = indent + 2 + strlen(PrsGen->Kfg->SNames[id]) + 13;
+      { int fstcol = indent + 2 + 
+                     strlen(PrsGen->Kfg->SNames[id]) + 
+                     strlen(PrsGen->ProdTab[idx].pname) + 13;
 
         for( j=0; j < PrsGen->ProdTab[idx].symcnt; ++j )
         {
@@ -1854,7 +2080,7 @@ static void printStateTab(PrsGen_T* PrsGen)
       (*prMsg)("\n");
       if( pos == PrsGen->MaxSymCnt + 1 )
       {
-        RedConflicts(PrsGen,(int)k,cl,curr->looks,readLst,True);
+        RedConflicts(PrsGen,Cfg,i,idx,(int)k,cl,curr->looks,readLst,True);
         ShiftConflicts(PrsGen,cl,curr->states,True);
       }
     }
@@ -1863,7 +2089,7 @@ static void printStateTab(PrsGen_T* PrsGen)
   OL_DEL_C(readLst);
 }
 
-static void countConflicts(PrsGen_T* PrsGen)
+static void countConflicts(PrsGen_T* PrsGen, PLR_Cfg Cfg)
 /* counts conflicts */
 { OL_Lst readLst = NEW_INTLIST; INT i, k;
 
@@ -1872,12 +2098,14 @@ static void countConflicts(PrsGen_T* PrsGen)
 
     for( k=0; k < OL_CNT(curr->kern); ++k )
     { INT ck = ( ! k ) ? FST_INTLE(curr->kern) : NXT_INTLE(curr->kern);
-      int pos = POSITION(ck); BS_Set cl = GET_LOOK(curr->looks,k);
+      int idx = PRODUCTION(ck) - 1, 
+          pos = POSITION(ck); 
+      BS_Set cl = GET_LOOK(curr->looks,k);
 
       OL_COPY_L(readLst,curr->kern);
       if( pos == PrsGen->MaxSymCnt + 1 )
       {
-        RedConflicts(PrsGen,(int)k,cl,curr->looks,readLst,False);
+        RedConflicts(PrsGen,Cfg,i,idx,(int)k,cl,curr->looks,readLst,False);
         ShiftConflicts(PrsGen,cl,curr->states,False);
       }
     }
@@ -1925,6 +2153,7 @@ PLR_Cfg PLR_createCfg(string Language, int version)
   cfg->TokKind  = NEW_INTTAB;
   cfg->ErrorNt  = OT_CREATE_ADT(bool);
   cfg->Prod     = NEW_PRODTAB;
+  cfg->Conflict = NEW_CONFLICTTAB;
   return( cfg );
 }
 
@@ -2015,11 +2244,12 @@ int PLR_addPR(PLR_Cfg Cfg, string PName, int Method, string NonTerm)
   BUG_VMIN(prod.pid,0);
   prod.pid     = GET_INTTE(PLR_C_IMP(Cfg)->NtIdx,prod.pid-1);
   prod.psymbol = NEW_PSYMTAB;
+  prod.idx     = OT_CNT(PLR_C_IMP(Cfg)->Prod);
   return( (int)INS_PROD(&prod,PLR_C_IMP(Cfg)->Prod) );
 }
 
 int PLR_addPT(PLR_Cfg Cfg, string Token, long sRow, long sCol)
-/* adds token 'Token' to current production of definition 'Cfg'; 
+/* adds (dynamic) token 'Token' to current production of definition 'Cfg'; 
    The symbol position 'sRow', 'sCol' is used as layout hint.
 */
 { PSDFN psym; INT idx, tki; int kind;
@@ -2039,6 +2269,44 @@ int PLR_addPT(PLR_Cfg Cfg, string Token, long sRow, long sCol)
   }
   assert0(!CFG_KEY(kind),"illegal token type");
   psym.istoken = True;
+  psym.dsymbol = -1;
+  psym.sRow    = sRow;
+  psym.sCol    = sCol;
+  return( (int)INS_PSYM(&psym,GET_PROD(PLR_C_IMP(Cfg)->Prod,idx)->psymbol) );
+}
+
+int PLR_addPD(PLR_Cfg Cfg, string Token, string DToken, long sRow, long sCol)
+/* adds token 'Token' as dynamic Token 'DToken' to current production of definition 'Cfg'; 
+   The symbol position 'sRow', 'sCol' is used as layout hint.
+*/
+{ PSDFN psym; INT idx, tki, dtki; int kind;
+
+  BUG_NULL(Cfg); BUG_NULL(Token);
+  idx          = OT_CNT(PLR_C_IMP(Cfg)->Prod) - 1;
+  BUG_VMIN(idx,-1);
+  tki          = FND_STRTE(PLR_C_IMP(Cfg)->Token,PLR_C_IMP(Cfg)->TkIdx,Token);
+  BUG_VMIN(tki,0);
+  psym.symbol  = GET_INTTE(PLR_C_IMP(Cfg)->TkIdx,tki-=1);
+  kind         = GET_INTTE(PLR_C_IMP(Cfg)->TokKind,psym.symbol);
+  while( CFG_KEY(kind) && (++tki) < OT_CNT(PLR_C_IMP(Cfg)->TkIdx) )
+  {
+    psym.symbol = GET_INTTE(PLR_C_IMP(Cfg)->TkIdx,tki);
+    if( !strcmp(GET_STRTE(PLR_C_IMP(Cfg)->Token,psym.symbol),Token) )
+      kind = GET_INTTE(PLR_C_IMP(Cfg)->TokKind,psym.symbol);
+  }
+  assert0(!CFG_KEY(kind),"illegal token type");
+  dtki         = FND_STRTE(PLR_C_IMP(Cfg)->Token,PLR_C_IMP(Cfg)->TkIdx,DToken);
+  BUG_VMIN(dtki,0);
+  psym.dsymbol = GET_INTTE(PLR_C_IMP(Cfg)->TkIdx,dtki-=1);
+  kind         = GET_INTTE(PLR_C_IMP(Cfg)->TokKind,psym.dsymbol);
+  while( CFG_KEY(kind) && (++dtki) < OT_CNT(PLR_C_IMP(Cfg)->TkIdx) )
+  {
+    psym.dsymbol = GET_INTTE(PLR_C_IMP(Cfg)->TkIdx,dtki);
+    if( !strcmp(GET_STRTE(PLR_C_IMP(Cfg)->Token,psym.dsymbol),DToken) )
+      kind = GET_INTTE(PLR_C_IMP(Cfg)->TokKind,psym.dsymbol);
+  }
+  assert0(!CFG_KEY(kind),"illegal dynamic token type");
+  psym.istoken = True;
   psym.sRow    = sRow;
   psym.sCol    = sCol;
   return( (int)INS_PSYM(&psym,GET_PROD(PLR_C_IMP(Cfg)->Prod,idx)->psymbol) );
@@ -2065,6 +2333,7 @@ int PLR_addPK(PLR_Cfg Cfg, string Keyword, long sRow, long sCol)
   }
   assert0(CFG_KEY(kind),"illegal keyword type");
   psym.istoken = True;
+  psym.dsymbol = -1;
   psym.sRow    = sRow;
   psym.sCol    = sCol;
   return( (int)INS_PSYM(&psym,GET_PROD(PLR_C_IMP(Cfg)->Prod,idx)->psymbol) );
@@ -2084,11 +2353,69 @@ int PLR_addPN(PLR_Cfg Cfg, string NonTerm, long sRow, long sCol)
   BUG_VMIN(psym.symbol,0);
   psym.symbol  = GET_INTTE(PLR_C_IMP(Cfg)->NtIdx,psym.symbol-1);
   psym.istoken = False;
+  psym.dsymbol = -1;
   psym.sRow    = sRow;
   psym.sCol    = sCol;
   return( (int)INS_PSYM(&psym,GET_PROD(PLR_C_IMP(Cfg)->Prod,idx)->psymbol) );
 }
 
+int PLR_addCCtx(PLR_Cfg Cfg, int StateIdx, string StateSym, string Token)
+/* adds conflict context (state, token) to definition 'Cfg' 
+*/
+{ CRULE conflict; INT idx;
+
+  BUG_NULL(Cfg); BUG_NULL(Token);
+  BUG_VNEQ(PLR_C_IMP(Cfg)->NtIdx,(OT_Tab)NULL);
+  BUG_VNEQ(PLR_C_IMP(Cfg)->TkIdx,(OT_Tab)NULL);
+  BUG_VNEQ(PLR_C_IMP(Cfg)->Prod,(OT_Tab)NULL);
+  conflict.StateIdx = StateIdx;
+  if( StateSym == NULL || *StateSym == '\0' )
+    conflict.StateSym = -1;
+  else
+  {
+    idx = (int)FND_STRTE(PLR_C_IMP(Cfg)->NonTerm,PLR_C_IMP(Cfg)->NtIdx,StateSym);
+    if( idx > 0 )
+    {
+      idx = OT_CNT(PLR_C_IMP(Cfg)->Token) + GET_INTTE(PLR_C_IMP(Cfg)->NtIdx,idx-1);
+    }
+    else
+    {
+      idx = (int)FND_STRTE(PLR_C_IMP(Cfg)->Token,PLR_C_IMP(Cfg)->TkIdx,StateSym);
+      BUG_VMIN(idx,0);
+      idx = GET_INTTE(PLR_C_IMP(Cfg)->TkIdx,idx-1);
+    }
+    conflict.StateSym = idx;
+  }
+  idx = (int)FND_STRTE(PLR_C_IMP(Cfg)->Token,PLR_C_IMP(Cfg)->TkIdx,Token);
+  BUG_VMIN(idx,0);
+  idx = GET_INTTE(PLR_C_IMP(Cfg)->TkIdx,idx-1);
+  conflict.TokenIdx = idx;
+  conflict.ProdIdx = NEW_INTTAB;
+  return( (int)INS_CONFLICT(&conflict,PLR_C_IMP(Cfg)->Conflict) );
+}
+
+int PLR_addCRule(PLR_Cfg Cfg, string NonTerm, string PName)
+/* adds rule i.e. production 'NonTerm'::'PName'  to current conflict of definition 'Cfg'; 
+*/
+{ INT idx, ntidx, i;
+
+  BUG_NULL(Cfg); BUG_NULL(NonTerm); BUG_NULL(PName);
+  idx = OT_CNT(PLR_C_IMP(Cfg)->Conflict) - 1;
+  BUG_VMIN(idx,-1);
+  ntidx = (int)FND_STRTE(PLR_C_IMP(Cfg)->NonTerm,PLR_C_IMP(Cfg)->NtIdx,NonTerm);
+  BUG_VMIN(ntidx,0);
+  ntidx = GET_INTTE(PLR_C_IMP(Cfg)->NtIdx,ntidx-1);
+  for( i=0; i < OT_CNT(PLR_C_IMP(Cfg)->Prod); ++i )
+  { PRDFN* prod = GET_PROD(PLR_C_IMP(Cfg)->Prod,i);
+    if( prod->pid == ntidx && !strcmp(prod->pname,PName) )
+    {
+      return( (int)INS_INTTE((int)prod->idx,GET_CONFLICT(PLR_C_IMP(Cfg)->Conflict,idx)->ProdIdx) );
+    }
+  }
+  assert0(False,"unknown production name");
+  return -1;
+}
+
 void PLR_delCfg(PLR_Cfg Cfg)
 /* removes grammar definition 'Cfg' */
 {
@@ -2102,6 +2429,7 @@ void PLR_delCfg(PLR_Cfg Cfg)
   OT_DEL_T(PLR_C_IMP(Cfg)->TokKind);
   OT_DEL_T(PLR_C_IMP(Cfg)->ErrorNt);
   OT_DEL_T(PLR_C_IMP(Cfg)->Prod);
+  OT_DEL_T(PLR_C_IMP(Cfg)->Conflict);
   FreeMem(Cfg);
 }
 
@@ -2122,6 +2450,7 @@ static PLR_Tab PLR_createTab_aux
   PrsGen.prMsg       = prExtMsg;
   PrsGen.profile     = verbose;
   PrsGen.conflictCnt = 0;
+  PrsGen.cruleCnt    = 0;
   PrsGen.version     = PLR_C_IMP(Cfg)->version;
   if( PrsGen.profile ) (*prMsg)("begin parse table creation ...\n");
   if( PrsGen.profile ) (*prMsg)("reading grammar information ...\n");
@@ -2138,19 +2467,23 @@ static PLR_Tab PLR_createTab_aux
   if( PrsGen.profile ) (*prMsg)("creating states ...\n");
   fillStateTab(&PrsGen);
   if( PrsGen.profile ) (*prMsg)("creating parse tables ...\n");
-  PTab = fillParseTab(&PrsGen);
+  PTab = fillParseTab(&PrsGen,Cfg);
   if( diagnose )
   {
     (*prMsg)("printing statistics ...\n");
     printFirstNtSets(&PrsGen);
-    printStateTab(&PrsGen);
+    printStateTab(&PrsGen,Cfg);
     printNtClasses(&PrsGen);
   }
-  else countConflicts(&PrsGen);
+  else countConflicts(&PrsGen,Cfg);
   ((PARSETAB*)PTab)->Conflicts = PrsGen.conflictCnt;
   if( PrsGen.conflictCnt )
   {
-    sprintf(buf,"%d conflicts. Use -diagnose !\n",PrsGen.conflictCnt);
+    sprintf
+    (
+      buf,"%d conflicts, %d solved by conflict rules. Use -diagnose !\n",
+      PrsGen.conflictCnt, PrsGen.cruleCnt
+    );
     (*prMsg)(buf);
   }
   if( PrsGen.profile ) (*prMsg)("deleting ...\n");
