@@ -1053,7 +1053,7 @@ static Scn_T ScnTable (ScnDfn_T scndfn, RegSet_T scanner)
       t = EdgeC[StaEdg[node->id]+i];
           EdgeC[StaEdg[node->id]+i] = EdgeC[edgcnt-1-i];
                                       EdgeC[edgcnt-1-i] = t;
-      t = EdgeS[StaEdg[node->id]+i];
+      t = (wc_char)EdgeS[StaEdg[node->id]+i];
           EdgeS[StaEdg[node->id]+i] = EdgeS[edgcnt-1-i];
                                       EdgeS[edgcnt-1-i] = t;
     }
@@ -1172,7 +1172,7 @@ static void pChar(wc_char wc, ScnDfn_T scndfn)
                   sprintf(buf,"%02x",c);
     }
   else
-    sprintf(buf,"%08lx",wc);
+    sprintf(buf,"%08lx",(long unsigned int)wc);
   (*prMsg)(buf);
 }
 
@@ -1208,7 +1208,11 @@ static void pNfaEdge(nfaEdge x, ScnDfn_T scndfn)
   }
   else
   {
-    sprintf(buf,"({%08lx..%08lx}, ", x->nfa_lower, x->nfa_upper);
+    sprintf
+    (
+      buf,"({%08lx..%08lx}, ", 
+      (long unsigned int)x->nfa_lower, (long unsigned int)x->nfa_upper
+    );
     (*prMsg)(buf);
   }
   pGraphList(x->nfa_toNodes,-1,(void (*)(Abs_T x,StdCPtr any))pSource,scndfn);
