@@ -209,7 +209,7 @@ void CTX_C_Modul(string Environ, CTX_T Ctx, c_bool shortform)
   for (i = 0; i < ctx->cnt; i++)
   {
     fprintf(tf,"  CTX_set(ctx,%2d,",i);
-    fprintf(tf,"\"%s\",%*s",ctx->tbl[i].ide,maxlen-strlen(ctx->tbl[i].ide),"");
+    fprintf(tf,"\"%s\",%*s",ctx->tbl[i].ide,(int)(maxlen-strlen(ctx->tbl[i].ide)),"");
     switch( ctx->tbl[i].cat )
     {
       case CTX_ARG : fprintf(tf,"CTX_ARG,"); break;
