@@ -328,7 +328,7 @@ void PGM_scan(Scn_Stream cStream, c_bool output, c_string cset, c_bool wprint)
           Stream_clin(cStream),
           Stream_ccol(cStream),
           s,
-          maxlen - strlen(s), ""
+          (int)(maxlen - strlen(s)), ""
         );
       }
       else
@@ -344,7 +344,7 @@ void PGM_scan(Scn_Stream cStream, c_bool output, c_string cset, c_bool wprint)
           Stream_clin(cStream),
           Stream_ccol(cStream),
           s,
-          maxlen - strlen(s), ""
+          (int)(maxlen - strlen(s)), ""
         );
         GS_fprint_utf8(STDOUT,t,False);
         FreeMem(t);
