@@ -21,6 +21,8 @@
          generic language support [gls].
 */
 
+#include "cfg_dfn.h"
+
 /*I------------------------------ Types ----------------------------------- */
 
 /*INTERFACE*/
@@ -87,7 +89,9 @@ bool GLS_Term_Lst(PT_Abs_Term x, GLS_Lst(PT_Abs_Term) *lst)
 {
   if ( PT_Abs_isNonTerm(x)
     && ( PT_Abs_product(x) == Nil_sym
-      || PT_Abs_product(x) == Cons_sym ) )
+      || PT_Abs_product(x) == Cons_sym 
+      || nilProd(symbolToString(PT_Abs_product(x)))
+      || consProd(symbolToString(PT_Abs_product(x))) ) )
   {
     if (lst != (GLS_Tok)NULL) *lst = (GLS_Lst(PT_Abs_Term))x; return True;
   }
@@ -98,7 +102,8 @@ bool GLS_Lst_nil(GLS_Lst(PT_Abs_Term) x)
 #define GLS_EMPTY(term) ( GLS_Lst_nil((PT_Abs_Term)(term)) )
 /* nil - selector */
 {
-  return PT_Abs_isNonTerm(x) && PT_Abs_product(x) == Nil_sym;
+  return PT_Abs_isNonTerm(x) && 
+         ( PT_Abs_product(x) == Nil_sym || nilProd(symbolToString(PT_Abs_product(x))) );
 }
 
 bool GLS_Lst_cons
@@ -109,7 +114,9 @@ bool GLS_Lst_cons
 )
 /* cons - selector */
 { 
-  if ( !PT_Abs_isNonTerm(x) || PT_Abs_product(x) != Cons_sym) return False;
+  if ( !PT_Abs_isNonTerm(x) || 
+       ( PT_Abs_product(x) != Cons_sym && !consProd(symbolToString(PT_Abs_product(x))) ) ) 
+    return False;
   if( (StdCPtr)fst != (StdCPtr)NULL ) *fst = PT_Abs_part(x,0);
   if( (StdCPtr)rst != (StdCPtr)NULL ) *rst = PT_Abs_part(x,1);
   return True;
