@@ -17,6 +17,8 @@
    nonterminal (styx version >= 1).
 */
 
+#include "cfg_dfn.h"
+
 /*I------------------------------ Types ----------------------------------- */
 
 /*INTERFACE*/
@@ -125,7 +127,9 @@ bool GLS_Term_Lst(PT_Term x, GLS_Lst(PT_Term) *lst)
 {
   if ( PT_isNonTerm(x)
     && ( PT_product(x) == Nil_sym
-      || PT_product(x) == Cons_sym ) )
+      || PT_product(x) == Cons_sym 
+      || nilProd(symbolToString(PT_product(x)))
+      || consProd(symbolToString(PT_product(x))) ) )
   {
     if (lst != (GLS_Tok)NULL) *lst = (GLS_Lst(PT_Term))x; return True;
   }
@@ -136,13 +140,16 @@ bool GLS_Lst_nil(GLS_Lst(PT_Term) x)
 #define GLS_EMPTY(term) ( GLS_Lst_nil((PT_Term)(term)) )
 /* nil - selector */
 {
-  return PT_isNonTerm(x) && PT_product(x) == Nil_sym;
+  return PT_isNonTerm(x) && 
+         ( PT_product(x) == Nil_sym || nilProd(symbolToString(PT_product(x))) );
 }
 
 bool GLS_Lst_cons(GLS_Lst(PT_Term) x, PT_Term* fst_t, GLS_Lst(PT_Term)* rst_t)
 /* cons - selector */
 { 
-  if ( !PT_isNonTerm(x) || PT_product(x) != Cons_sym) return False;
+  if ( !PT_isNonTerm(x) || 
+       ( PT_product(x) != Cons_sym && !consProd(symbolToString(PT_product(x))) ) ) 
+    return False;
   if( ! PT_isXaron(x) )
   {
     x = GLS_keycom_Skip(PT_parts(x));
