@@ -135,7 +135,7 @@ void patchhead(void)
   }
 }
 
-bool getline(void)
+bool c_getline(void)
 {
   if( scan_line != NULL ) FreeMem(scan_line);
   if ((scan_line = Line_get(SysIn)) == NULL)
@@ -510,10 +510,10 @@ void flushFuncs(void)
       fprintf
       (
         SysOut, "%s%*s %s;%*s/* %s%*s */\n",
-        Func[i].typ, xltyp-strlen(Func[i].typ),"",
-        Func[i].fun, xlfun-strlen(Func[i].fun)+
-                     LineLength-xltyp-1-xlfun-1-xlcom-6,"",
-        Func[i].com, xlcom-strlen(Func[i].com),""
+        Func[i].typ, (int)(xltyp-strlen(Func[i].typ)),"",
+        Func[i].fun, (int)(xlfun-strlen(Func[i].fun)+
+                     LineLength-xltyp-1-xlfun-1-xlcom-6),"",
+        Func[i].com, (int)(xlcom-strlen(Func[i].com)),""
       );
     else
       fprintf
@@ -630,7 +630,7 @@ void copyBlock(bool skipFirst, bool DocBlock, bool forcedDocBlock)
     {
       t = convBlock(temp); FreeMem(temp); temp = t;
     }
-    if( getline() && CTypConv )
+    if( c_getline() && CTypConv )
     {
       t = convBlock(line); FreeMem(line); scan_line = line = t;
     }
@@ -657,7 +657,7 @@ void copyBlock(bool skipFirst, bool DocBlock, bool forcedDocBlock)
       line[rgh+1] = 0;
       pushFuncLine(temp,StrCopy(line+lft));
     }
-    while( line[0] != 0 && line[0] != '{') getline();
+    while( line[0] != 0 && line[0] != '{') c_getline();
     return;
 Ordinary:
     if( GenExp && line[0] != 0 )
@@ -703,7 +703,7 @@ Ordinary:
       ext = Sink_open();
     Sink_printf(ext,"%s\n",line);
   }
-  while(getline() && line[0] != 0 && line[0] != '{' )
+  while(c_getline() && line[0] != 0 && line[0] != '{' )
   {
     if( extflg &=
         ( !beginswith("/*") && !beginswith("//") && !beginswith("#") ))
@@ -765,7 +765,7 @@ Ordinary:
 
 void skipDoc(void)
 {
-  while(getline() && strcmp(line,"#endif") != 0) /* skip */;
+  while(c_getline() && strcmp(line,"#endif") != 0) /* skip */;
 }
 
 void copyDoc
@@ -808,7 +808,7 @@ void copyDoc
   }
   if( t2 == (string)NULL)
   {
-    while(getline() )
+    while(c_getline() )
     {
       fprintf(SysOut,"%s\n",line);
       if( (t2=strstr(line,szEndTag)) != (string)NULL)
@@ -850,7 +850,7 @@ void copyToI(string szEndTag, bool forcedDocBlock)
   if( CTypConv ) pSnk = Sink_open();
   if( forcedDocBlock )
     fprintf(SysDoc,"<br><pre>\n");
-  while(getline() && strcmp(line,szEndTag) != 0)
+  while(c_getline() && strcmp(line,szEndTag) != 0)
   {
     if( CTypConv ) Sink_printf(pSnk,"%s\n",line);
     else           
@@ -900,7 +900,7 @@ void convertText(void)
   Shift       = False;
   OnOff       = True; /* INTERFACE_ON ! */
   mainSeen    = False;
-  if (getline()) copyBlock(False,False,False);
+  if (c_getline()) copyBlock(False,False,False);
   if (!Patched) fprintf(STDERR,"Warning: %s missing header comment.\n",cfid);
   Patched = True;
   fprintf(SysOut,"/* File generated by 'ctoh'. Don't change manually. */\n");
@@ -924,7 +924,7 @@ void convertText(void)
     fprintf(SysOut,"#endif\n");
     fprintf(SysOut,"\n");
   }
-  while (getline())
+  while (c_getline())
   {
     if( CLinkageFlag == False && IncludeSeen == True )
     {
