@@ -1093,6 +1093,7 @@ static void SD_load_com(StyDoc_T pStyDoc)
             assert0(   styxQlxDfn_defn((styxQlxDfn)t,_,_,_,&pIde,_,_)
                     || styxQlxDfn_igrp((styxQlxDfn)t,&pIde)
                     || styxQlxDfn_xgrp((styxQlxDfn)t,&pIde)
+                    || styxQlxDfn_tgrp((styxQlxDfn)t,&pIde)
                     || styxQlxDfn_mgrp((styxQlxDfn)t,&pIde,_), "");
             if( !MAP_defined(pStyDoc->pDfnCom,GLS_Tok_symbol(pIde)) )
             {
@@ -1171,7 +1172,8 @@ static void SD_load_lex(GLS_Lst(styxQlxDfn) pQDfns, StyDoc_T pStyDoc)
         MAP_dfndom(pStyDoc->pTMap,pTSym,pQDfn);
     }
     else
-    if( styxQlxDfn_igrp(pQDfn,&pIde) || styxQlxDfn_xgrp(pQDfn,&pIde) ||
+    if( styxQlxDfn_igrp(pQDfn,&pIde) || styxQlxDfn_xgrp(pQDfn,&pIde) || 
+        styxQlxDfn_tgrp(pQDfn,&pIde) ||
         styxQlxDfn_mgrp(pQDfn,&pIde,_) )
     {
       if( ! MAP_defined(pStyDoc->pGMap,GLS_Tok_symbol(pIde)) )
@@ -1784,7 +1786,7 @@ static c_bool SD_load(StyDoc_T* ppStyDoc)
     styxSource_root(pSrc,_,&pIde,&pQDfns,&pOptCfg);
     SD_load_com(pStyDoc);
     SD_load_lex(pQDfns,pStyDoc);
-    if( styxOptCfg_cfg(pOptCfg,&pDfns) && ! GLS_EMPTY(pDfns) )
+    if( styxOptCfg_cfg(pOptCfg,&pDfns,_) && ! GLS_EMPTY(pDfns) )
     {
       pStyDoc->pTab = PLR_getTab_env(binpath,GLS_Tok_string(pIde));
       if( pStyDoc->pTab != (PLR_Tab)NULL &&
