@@ -37,7 +37,7 @@ int main(int argc, string argv[])
   );
   errcnt = XML_load_file(xmlctx,file,cset,dtd,all);
   XML_get_trees(xmlctx,_,&trees);
-HERE;
+//HERE;
   MAP_forItrAsg(dom,rng,itr,trees)
   {
     printf("\nParsing results for '%s':\n",symbolToString(dom));
