@@ -1630,7 +1630,7 @@ static bool getCommands(string cmdtyp,int* fstidx, int* lstidx)
 
 static void execCommands(string cmdtyp)
 { char tmpbuf[CMDLEN+1], cmdbuf[CMDLEN+1];
-  int fstidx, lstidx, i, l, l1 = 0, l2 = 0;
+  int fstidx = 0, lstidx = 0, i, l, l1 = 0, l2 = 0;
   if (cnt_targets > 0 && ! getCommands(cmdtyp,&fstidx,&lstidx))
   {
     fprintf(stderr,"%s(%d): syntax error.\n",fileid,lineno);
