@@ -140,7 +140,7 @@ int lmain(int argc, char* argv[])
   short z = x >> 16;
   long yy = x >> 0;
   short zz = x >> 0;
-  printf("SIZE=%d\n",sizeof(long long int));
+  printf("SIZE=%ld\n",sizeof(long long int));
   printf("LONG-HI=%ld\n",y);
   printf("LONG-LO=%ld\n",yy);
   printf("SHORT-HI=%d\n",z);
